Action<T extends Intent> class

An action that can be invoked in response to an Intent.

Implementers

Constructors

Action()
Creates an Action.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(T intent) Object?
Invokes this action with the given intent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited