ActionDispatcher class

Dispatches Actions in response to Intents.

Constructors

ActionDispatcher()
Creates an ActionDispatcher.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invokeAction(Action<Intent> action, Intent intent) Object?
Invokes action with intent and returns the result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited