of static method
Retrieves the nearest action map from the widget tree.
Implementation
static Map<Type, Action>? of(BuildContext context) {
final scope = context.dependOnInheritedWidgetOfExactType<_ActionsScope>();
return scope?.actions;
}
Retrieves the nearest action map from the widget tree.
static Map<Type, Action>? of(BuildContext context) {
final scope = context.dependOnInheritedWidgetOfExactType<_ActionsScope>();
return scope?.actions;
}