AppLogger class

Application-wide logger that writes messages to a log file.

Constructors

AppLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dispose() → void
Closes the log file and ends the current logging session.
initialize() → void
Opens the log file and starts a new logging session.
log(String message) → void
Writes a timestamped message to the log file.