dispose static method
void
dispose()
Closes the log file and ends the current logging session.
Implementation
static void dispose() {
_sink?.writeln('--- Log Session Ended: ${DateTime.now()} ---');
_sink?.close();
}
Closes the log file and ends the current logging session.
static void dispose() {
_sink?.writeln('--- Log Session Ended: ${DateTime.now()} ---');
_sink?.close();
}