BindingBase class abstract

The abstract base class for all bindings.

Bindings are singletons that glue the framework to platform services.

Implementers

Constructors

BindingBase()
Creates a BindingBase and immediately calls initInstances.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initInstances() → void
Called during construction to initialize binding singletons.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkInstance<T>(T? instance) → T
Throws if instance is null, otherwise returns it.