CallbackAction class

An Action subclass that delegates invocation to a callback.

Inheritance

Constructors

CallbackAction({required Object? onInvoke(Intent)})
Creates a CallbackAction that calls onInvoke when triggered.

Properties

hashCode int
The hash code for this object.
no setterinherited
onInvoke Object? Function(Intent)
The callback to invoke when this action is triggered.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(Intent intent) Object?
Invokes this action with the given intent.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited