empty constant
Cell
const empty
An empty cell containing a single space with no styling.
Implementation
static const empty = Cell(' ');
An empty cell containing a single space with no styling.
static const empty = Cell(' ');