Center class

Centers its child within itself.

Equivalent to Align(alignment: Alignment.center, child: child).

Inheritance

Constructors

Center({Key? key, Widget? child})
Creates a Center widget with the given optional child.
const

Properties

child Widget?
The widget to center within the available space.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates the Element for this widget.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited