removeListener method

void removeListener(
  1. dynamic listener()
)

Remove a previously registered closure from the list of closures that are notified when the object changes.

If the given listener is not registered, the call is ignored.

Implementation

void removeListener(Function() listener) {
  _listeners.remove(listener);
}