Clipboard class abstract

A simple in-memory clipboard for cut, copy, and paste operations.

Constructors

Clipboard()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

hasData bool
Whether the clipboard currently contains data.
no setter

Static Methods

getData() Future<String?>
Retrieves the current clipboard content, if any.
setData(String text) Future<void>
Stores text in the clipboard.