Column class

A Flex that lays out children in a vertical line.

Use MainAxisAlignment and CrossAxisAlignment to control spacing. Children can be wrapped in Expanded or Flexible to distribute space.

Inheritance

Constructors

Column({Key? key, required List<Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisSize mainAxisSize = MainAxisSize.max})
Creates a Column with the given children and alignment options.
const

Properties

children List<Widget>
The list of child widgets.
finalinherited
crossAxisAlignment CrossAxisAlignment
How children are aligned on the cross axis.
finalinherited
direction Axis
The direction along which children are laid out.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
mainAxisAlignment MainAxisAlignment
How children are distributed along the main axis.
finalinherited
mainAxisSize MainAxisSize
How much space the flex should occupy on the main axis.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() MultiChildRenderObjectElement
Creates the Element for this widget.
inherited
createRenderObject(BuildContext context) RenderFlex
Creates the RenderObject for this widget.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
Updates the renderObject to reflect the current widget configuration.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited