rebuild method
void
rebuild()
Rebuilds the element by calling build and updating the child.
Implementation
void rebuild() => _child = updateChild(_child, build());
Rebuilds the element by calling build and updating the child.
void rebuild() => _child = updateChild(_child, build());