DataColumn class

Configuration for a single column in a DataTable.

Constructors

DataColumn({required String label, bool numeric = false, void onSort(int columnIndex, bool ascending)?})
Creates a DataColumn with the given label.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The header label for this column.
final
numeric bool
Whether this column contains numeric data (right-aligned).
final
onSort → void Function(int columnIndex, bool ascending)?
An optional callback when the column header is activated for sorting.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited