DataRow class

A single row of DataCells in a DataTable.

Constructors

DataRow({required List<DataCell> cells, void onSelectChanged(bool selected)?, bool selected = false})
Creates a DataRow with the given cells.
const

Properties

cells List<DataCell>
The cell values for this row.
final
hashCode int
The hash code for this object.
no setterinherited
onSelectChanged → void Function(bool selected)?
Called when the row selection state changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
Whether this row is currently selected.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited