EdgeInsets class
Immutable insets for each edge of a terminal rectangle.
Follows Flutter's EdgeInsets API: EdgeInsets.all, EdgeInsets.symmetric, EdgeInsets.only, and EdgeInsets.fromLTRB.
Constructors
- EdgeInsets.all(int v)
-
Creates insets where all four edges are the same value
v.const - EdgeInsets.fromLTRB(int left, int top, int right, int bottom)
-
Creates insets from individual left, top, right, and bottom values.
const
- EdgeInsets.only({int top = 0, int right = 0, int bottom = 0, int left = 0})
-
Creates insets with only the specified non-zero edges.
const
- EdgeInsets.symmetric({int vertical = 0, int horizontal = 0})
-
Creates insets with symmetric vertical and horizontal values.
const
Properties
- bottom → int
-
The inset from the bottom edge.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- horizontal → int
-
The total horizontal inset (left + right).
no setter
- left → int
-
The inset from the left edge.
final
- right → int
-
The inset from the right edge.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int
-
The inset from the top edge.
final
- vertical → int
-
The total vertical inset (top + bottom).
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator +(
EdgeInsets other) → EdgeInsets -
Returns the sum of these insets and
other. -
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- zero → const EdgeInsets
- Zero insets on all sides.