mount method
Adds this element to the tree at the given parent.
Implementation
void mount(Element? parent) {
_parent = parent;
if (widget.key case final GlobalKey key) {
key._register(this);
}
}
Adds this element to the tree at the given parent.
void mount(Element? parent) {
_parent = parent;
if (widget.key case final GlobalKey key) {
key._register(this);
}
}