parent property
Element?
get
parent
The parent of this element in the tree, or null if this is the root.
Implementation
Element? get parent => _parent;
The parent of this element in the tree, or null if this is the root.
Element? get parent => _parent;