ExpansionTileController class

Controls the expanded/collapsed state of an ExpansionTile.

Obtain via ExpansionTile.of and call toggle, expand, or collapse.

Inheritance

Constructors

ExpansionTileController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isExpanded bool
Whether the tile is currently expanded.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(dynamic listener()) → void
Register a closure to be called when the object changes.
inherited
collapse() → void
Collapses the tile if currently expanded.
dispose() → void
Discards any resources used by the object.
inherited
expand() → void
Expands the tile if currently collapsed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(dynamic listener()) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggle() → void
Toggles between expanded and collapsed states.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited