ExpansionTileParentData class

Parent data for children of RenderExpansionTile, storing their offset.

Inheritance

Constructors

ExpansionTileParentData()

Properties

hashCode int
The hash code for this object.
no setterinherited
offset Offset
The offset at which this child is painted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited