flex property
The flex factor controlling how much space this child takes relative to other flexible children.
Implementation
final int flex;
The flex factor controlling how much space this child takes relative to other flexible children.
final int flex;