popDialogScope method
void
popDialogScope()
Pops the current focus scope, restoring the previous one.
Implementation
void popDialogScope() {
_popScope();
}
Pops the current focus scope, restoring the previous one.
void popDialogScope() {
_popScope();
}