pushDialogScope method
void
pushDialogScope()
Pushes a new focus scope, typically for a dialog.
Implementation
void pushDialogScope() {
_pushScope();
}
Pushes a new focus scope, typically for a dialog.
void pushDialogScope() {
_pushScope();
}