FocusNode class

Represents a focus scope node in the focus tree.

Each FocusNode can receive or relinquish keyboard focus. Use Focus widget to attach a FocusNode to the tree, and FocusScopeNode to create focus boundaries.

Inheritance

Constructors

FocusNode({bool canRequestFocus = true})
Creates a FocusNode with an optional canRequestFocus flag.

Properties

canRequestFocus bool
Whether this node is allowed to request focus.
getter/setter pair
hasFocus bool
Whether this node currently has keyboard focus.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
onKeyEvent ↔ dynamic Function(KeyEvent)?
An optional callback invoked when a key event reaches this node.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trapFocus bool
When true, focus is trapped within this node's subtree.
getter/setter pair

Methods

addListener(dynamic listener()) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(dynamic listener()) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
requestFocus() → void
Requests keyboard focus for this node.
toString() String
A string representation of this object.
inherited
unfocus() → void
Removes focus from this node.

Operators

operator ==(Object other) bool
The equality operator.
inherited