removeNode method
Removes node from this scope and transfers focus if needed.
Implementation
void removeNode(FocusNode node) {
final index = _nodes.indexOf(node);
if (index != -1) {
_removeNodeAtIndex(node, index);
}
}
Removes node from this scope and transfers focus if needed.
void removeNode(FocusNode node) {
final index = _nodes.indexOf(node);
if (index != -1) {
_removeNodeAtIndex(node, index);
}
}