builder property
Builds the visual representation using the current field state.
Implementation
final Widget Function(FormFieldState<T>) builder;
Builds the visual representation using the current field state.
final Widget Function(FormFieldState<T>) builder;