build method
Describes the part of the user interface represented by this state.
Implementation
@override
Widget build(BuildContext context) {
return widget.builder(this);
}
Describes the part of the user interface represented by this state.
@override
Widget build(BuildContext context) {
return widget.builder(this);
}