updateShouldNotify method
Whether the widgets that depend on this widget should be rebuilt when
oldWidget is replaced by this widget.
Implementation
@override
bool updateShouldNotify(FormScope oldWidget) =>
formState != oldWidget.formState;
Whether the widgets that depend on this widget should be rebuilt when
oldWidget is replaced by this widget.
@override
bool updateShouldNotify(FormScope oldWidget) =>
formState != oldWidget.formState;