FutureBuilder<T> class

Widget that builds itself based on the latest snapshot of interaction with a Future.

Inheritance

Constructors

FutureBuilder({Key? key, Future<T>? future, T? initialData, required AsyncWidgetBuilder<T> builder})
Creates a widget that builds itself based on the latest snapshot of interaction with a Future.
const

Properties

builder AsyncWidgetBuilder<T>
The build strategy currently used by this builder.
final
future Future<T>?
The asynchronous computation to which this builder is currently connected.
final
hashCode int
The hash code for this object.
no setterinherited
initialData → T?
The data that will be used to create the initial snapshot.
final
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates the Element for this widget.
inherited
createState() State<FutureBuilder<T>>
Creates the mutable state for this widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited