GlobalKey class

A key that is unique across the entire app, analogous to Flutter's GlobalKey.

Provides access to the associated element and widget from anywhere in the widget tree.

Inheritance

Constructors

GlobalKey()

Properties

currentElement Element?
The current element associated with this key, or null if unmounted.
no setter
currentWidget Widget?
The current widget associated with this key, or null if unmounted.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited