currentWidget property
Widget?
get
currentWidget
The current widget associated with this key, or null if unmounted.
Implementation
Widget? get currentWidget => _currentElement?.widget;
The current widget associated with this key, or null if unmounted.
Widget? get currentWidget => _currentElement?.widget;