build method
Describes the part of the user interface represented by this widget.
Implementation
@override
Widget build(BuildContext context) {
return Text(
icon,
style: color == null ? const TextStyle() : TextStyle(color: color),
);
}
Describes the part of the user interface represented by this widget.
@override
Widget build(BuildContext context) {
return Text(
icon,
style: color == null ? const TextStyle() : TextStyle(color: color),
);
}