Icons class

Common icon glyphs for use with Icon or Text.

Constructors

Icons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

arrowDown → const String
A downward arrow glyph.
arrowDownAscii → const String
ASCII fallback for downward arrow.
arrowLeft → const String
A leftward arrow glyph.
arrowLeftAscii → const String
ASCII fallback for leftward arrow.
arrowRight → const String
A rightward arrow glyph.
arrowRightAscii → const String
ASCII fallback for rightward arrow.
arrowUp → const String
An upward arrow glyph.
arrowUpAscii → const String
ASCII fallback for upward arrow.
check → const String
A check mark glyph.
checkAscii → const String
ASCII fallback for check mark.
cross → const String
A cross mark glyph.
crossAscii → const String
ASCII fallback for cross mark.
error → const String
An error icon glyph.
file → const String
A file icon glyph.
folder → const String
A folder icon glyph.
info → const String
An info icon glyph.
A menu/hamburger icon glyph.
minus → const String
A minus sign glyph.
plus → const String
A plus sign glyph.
A search/magnifier icon glyph.
settings → const String
A settings/gear icon glyph.
warning → const String
A warning icon glyph.