unmount method
Removes this element from the tree and releases resources.
Implementation
@override
void unmount() {
for (final dependent in _dependents) {
dependent._dependencies?.remove(this);
}
_dependents.clear();
super.unmount();
}
Removes this element from the tree and releases resources.
@override
void unmount() {
for (final dependent in _dependents) {
dependent._dependencies?.remove(this);
}
_dependents.clear();
super.unmount();
}