InheritedWidget class abstract

A widget that propagates information down the tree, analogous to Flutter's InheritedWidget.

When an InheritedWidget changes, all descendants that registered a dependency via BuildContext.dependOnInheritedWidgetOfExactType are rebuilt.

Inheritance
Implementers

Constructors

InheritedWidget({Key? key, required Widget child})
Creates an InheritedWidget.
const

Properties

child Widget
The widget below this inherited widget in the tree.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() InheritedElement
Creates the Element for this widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(covariant InheritedWidget oldWidget) bool
Whether the widgets that depend on this widget should be rebuilt when oldWidget is replaced by this widget.

Operators

operator ==(Object other) bool
The equality operator.
inherited