updateShouldNotify abstract method
Whether the widgets that depend on this widget should be rebuilt when
oldWidget is replaced by this widget.
Implementation
bool updateShouldNotify(covariant InheritedWidget oldWidget);
Whether the widgets that depend on this widget should be rebuilt when
oldWidget is replaced by this widget.
bool updateShouldNotify(covariant InheritedWidget oldWidget);