Key class abstract

An identification key for widgets, analogous to Flutter's Key.

Keys control how the framework replaces widgets in the tree when reconfiguring, enabling preservation of state across widget changes.

Implementers

Constructors

Key()
Creates a Key.
const
Key.empty()
Creates a const key with an empty value.
const
Key.value(String value)
Creates a ValueKey with the given value.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited