KeyFinder class

Inheritance

Constructors

KeyFinder(Key key)
const

Properties

evaluatesToSingleWidget bool
no setterinherited
exists bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
key Key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

byKey(Key key) Finder
inherited
byType<T extends Widget>() Finder
inherited
evaluate() Element?
inherited
evaluateAll() List<Element>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text(String text) Finder
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited