KeyboardBackend class abstract

Abstract interface for keyboard input backends.

Implementers

Constructors

KeyboardBackend()

Properties

hashCode int
The hash code for this object.
no setterinherited
keyEvents Stream<KeyEvent>
A stream of parsed keyboard events.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Releases resources used by the keyboard backend.
initialize() → void
Initializes the keyboard backend for capturing input.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited