selectedBuilder property
A builder that creates the widget for the currently selected item.
Implementation
final Widget Function(T item) selectedBuilder;
A builder that creates the widget for the currently selected item.
final Widget Function(T item) selectedBuilder;