unselectedBuilder property
A builder that creates the widget for unselected items.
Implementation
final Widget Function(T item) unselectedBuilder;
A builder that creates the widget for unselected items.
final Widget Function(T item) unselectedBuilder;