MainAxisAlignment enum

How children should be placed along the main axis of a flex layout.

Inheritance
Available extensions

Values

start → const MainAxisAlignment

Place children at the start of the main axis.

end → const MainAxisAlignment

Place children at the end of the main axis.

center → const MainAxisAlignment

Place children at the center of the main axis.

spaceBetween → const MainAxisAlignment

Place children evenly with no space before the first or after the last.

spaceAround → const MainAxisAlignment

Place children evenly with equal space before the first and after the last.

spaceEvenly → const MainAxisAlignment

Place children evenly with equal space between every pair and at the edges.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MainAxisAlignment>
A constant List of the values in this enum, in order of their declaration.