updateShouldNotify method
Whether descendant widgets should be notified when data changes.
Implementation
@override
bool updateShouldNotify(MediaQuery oldWidget) => data != oldWidget.data;
Whether descendant widgets should be notified when data changes.
@override
bool updateShouldNotify(MediaQuery oldWidget) => data != oldWidget.data;