MediaQueryData class
Contains terminal dimensions and safe area insets.
Use MediaQuery.of to obtain the current MediaQueryData, which provides size (terminal columns × rows) and padding (safe area insets).
Constructors
- MediaQueryData({required Size size, EdgeInsets padding = EdgeInsets.zero})
-
Creates a MediaQueryData with the given
sizeand optionalpadding.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- padding → EdgeInsets
-
Safe area insets (e.g., for status bars).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
The terminal size in columns × rows.
final
Methods
-
copyWith(
{Size? size, EdgeInsets? padding}) → MediaQueryData - Creates a copy of this object with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override