didPop method
Called when this route has been popped off the navigator.
Implementation
@override
void didPop(T? result) {
FocusManager.instance.popDialogScope();
super.didPop(result);
}
Called when this route has been popped off the navigator.
@override
void didPop(T? result) {
FocusManager.instance.popDialogScope();
super.didPop(result);
}