didPush method
Called when this route has been pushed onto the navigator.
Implementation
@override
void didPush() {
super.didPush();
FocusManager.instance.pushDialogScope();
}
Called when this route has been pushed onto the navigator.
@override
void didPush() {
super.didPush();
FocusManager.instance.pushDialogScope();
}