pop static method
Pops the top route off the navigator nearest to context.
Implementation
static bool pop(BuildContext context, [Object? result]) {
return of(context).pop(result);
}
Pops the top route off the navigator nearest to context.
static bool pop(BuildContext context, [Object? result]) {
return of(context).pop(result);
}