push<T> static method
Pushes the given route onto the navigator nearest to context.
Implementation
static Future<T?> push<T>(BuildContext context, Route route) {
return of(context).push(route);
}
Pushes the given route onto the navigator nearest to context.
static Future<T?> push<T>(BuildContext context, Route route) {
return of(context).push(route);
}