NavigatorObserver class abstract

An observer that receives notifications about route transitions, analogous to Flutter's NavigatorObserver.

Implementers

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didPop(Route route, Route? previousRoute) → void
Called when a route has been popped off the navigator.
didPush(Route route, Route? previousRoute) → void
Called when a route has been pushed onto the navigator.
didReplace({Route? newRoute, Route? oldRoute}) → void
Called when a route has been replaced by another route.
didStartUserGesture(Route route, Route? previousRoute) → void
Called when the user starts a gesture to navigate.
didStopUserGesture() → void
Called when the user stops a navigation gesture.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited