OutputBuffer constructor
OutputBuffer(
- Terminal terminal
Creates an OutputBuffer for the given terminal and initializes the grid.
Implementation
OutputBuffer(this.terminal) {
resize();
}
Creates an OutputBuffer for the given terminal and initializes the grid.
OutputBuffer(this.terminal) {
resize();
}