smartClear method
void
smartClear()
Fills the grid with empty cells while preserving the previous frame for diffing.
Implementation
void smartClear() {
clear();
}
Fills the grid with empty cells while preserving the previous frame for diffing.
void smartClear() {
clear();
}