Overlay class

A widget that stacks its child and overlay entries, analogous to Flutter's Overlay.

Inheritance

Constructors

Overlay({Key? key, required Widget child})
Creates an Overlay.
const

Properties

child Widget
The widget rendered below all overlay entries.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates the Element for this widget.
inherited
createState() State<Overlay>
Creates the mutable state for this widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) OverlayState?
Returns the OverlayState of the nearest Overlay ancestor.