PageRoute<T> class

A route backed by a builder function, analogous to Flutter's PageRoute.

Inheritance

Constructors

PageRoute({required RouteBuilder builder, RouteSettings? settings})
Creates a PageRoute.

Properties

builder RouteBuilder
The builder that creates this route's widget.
final
canPop bool
Whether this route can be popped.
no setterinherited
fullScreenRender bool
Whether this route renders as a full screen overlay.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isCurrent bool
Whether this route is the top-most route in the navigator.
no setterinherited
isFirst bool
Whether this route is the first (root) route.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings?
Optional configuration for this route.
finalinherited

Methods

buildPage(BuildContext context) Widget
Builds the widget for this route's page.
override
didPop(T? result) → void
Called when this route has been popped off the navigator.
inherited
didPush() → void
Called when this route has been pushed onto the navigator.
inherited
didReplace(Route? oldRoute) → void
Called when this route has been replaced by another route.
inherited
dispose() → void
Called when this route has been removed from the navigator.
inherited
install() → void
Called when the route is first added to the navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited