performLayout method
Called to perform the actual layout computation for this render object.
Implementation
@override
void performLayout(Constraints constraints) {
size = Size(_textWidth + 4, 1);
}
Called to perform the actual layout computation for this render object.
@override
void performLayout(Constraints constraints) {
size = Size(_textWidth + 4, 1);
}