RenderDropdownMenu class
Render object that paints the open dropdown menu popup with selectable items.
- Inheritance
-
- Object
- RenderObject
- RenderBox
- RenderDropdownMenu
Constructors
-
RenderDropdownMenu({required List<
DropdownMenuItem> items, required int selectedIndex, required Color dropdownColor, required Color focusColor}) - Creates a RenderDropdownMenu with the given items and visual configuration.
Properties
- dropdownColor ↔ Color
-
The background color of unselected items.
getter/setter pair
- focusColor ↔ Color
-
The background color of the selected item.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSize → bool
-
Whether this render object has been laid out and has a size.
no setterinherited
- height → int
-
The height of this render box in terminal rows.
no setterinherited
- isRelayoutBoundary → bool
-
Whether this render object acts as a relayout boundary.
no setterinherited
-
items
↔ List<
DropdownMenuItem> -
The list of menu items to display.
getter/setter pair
- needsPaint → bool
-
Whether this render object needs to be repainted.
no setterinherited
- parent ↔ RenderObject?
-
The parent of this render object, or
nullif this is the root.getter/setter pairinherited - parentData ↔ ParentData?
-
Optional data associated with this render object by its parent.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex ↔ int
-
The index of the currently highlighted item.
getter/setter pair
- size ↔ Size?
-
The current size of this render object after layout.
getter/setter pairinherited
- width → int
-
The width of this render box in terminal columns.
no setterinherited
Methods
-
clearNeedsPaint(
) → void -
Clears the needs-paint flag, indicating painting is up to date.
inherited
-
layout(
Constraints constraints, {bool parentUsesSize = true}) → void -
Performs layout on this render object using the given
constraints.inherited -
markNeedsLayout(
) → void -
Marks this render object as needing layout and paint.
inherited
-
markNeedsPaint(
) → void -
Marks this render object as needing to be repainted.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset offset) → void -
Paints this render object into the given
contextatoffset.override -
performLayout(
Constraints constraints) → void -
Called to perform the actual layout computation for this render object.
override
-
setRelayoutBoundary(
bool value) → void -
Marks this render object as a relayout boundary or not.
inherited
-
setupParentData(
RenderObject child) → void -
Initializes parentData for the given
childif not already set.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited