RenderLinearProgressIndicator class

Inheritance

Constructors

RenderLinearProgressIndicator({required double? value, required double animValue, required Color backgroundColor, required Color color, int? indicatorWidth})

Properties

animValue double
getter/setter pair
backgroundColor Color
getter/setter pair
color Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
indicatorWidth int?
getter/setter pair
isRelayoutBoundary bool
no setterinherited
needsPaint bool
no setterinherited
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
value double?
getter/setter pair
width int
no setterinherited

Methods

clearNeedsPaint() → void
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
override
performLayout(Constraints constraints) → void
override
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited