RenderPadding class

The render object for Padding, which insets its child by the given EdgeInsets.

Inheritance

Constructors

RenderPadding({required EdgeInsets padding})
Creates a RenderPadding with the given padding.

Properties

child RenderBox?
The single child of this render object, or null if none.
getter/setter pairinherited
hasChild bool
Whether this render object currently has a child.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
Whether this render object has been laid out and has a size.
no setterinherited
height int
The height of this render box in terminal rows.
no setterinherited
isRelayoutBoundary bool
Whether this render object acts as a relayout boundary.
no setterinherited
needsPaint bool
Whether this render object needs to be repainted.
no setterinherited
padding EdgeInsets
The amount of inset to apply.
getter/setter pair
parent RenderObject?
The parent of this render object, or null if this is the root.
getter/setter pairinherited
parentData ParentData?
Optional data associated with this render object by its parent.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
The current size of this render object after layout.
getter/setter pairinherited
width int
The width of this render box in terminal columns.
no setterinherited

Methods

clearNeedsPaint() → void
Clears the needs-paint flag, indicating painting is up to date.
inherited
computeChildOffset(Offset parentOffset, Size childSize) Offset
Offsets the child by the left and top padding.
override
computeSizeFromChild(BoxConstraints constraints, Size childSize) Size
Expands the child size by adding the padding.
override
computeSizeWithoutChild(BoxConstraints constraints) Size
Returns the size when there is no child (just the padding dimensions).
override
getConstraintsForChild(BoxConstraints constraints) BoxConstraints
Deflates the incoming constraints by the padding amount.
override
layout(Constraints constraints, {bool parentUsesSize = true}) → void
Performs layout on this render object using the given constraints.
inherited
markNeedsLayout() → void
Marks this render object as needing layout and paint.
inherited
markNeedsPaint() → void
Marks this render object as needing to be repainted.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
Paints this render object into the given context at offset.
inherited
performLayout(Constraints constraints) → void
Called to perform the actual layout computation for this render object.
inherited
setRelayoutBoundary(bool value) → void
Marks this render object as a relayout boundary or not.
inherited
setupParentData(RenderObject child) → void
Initializes parentData for the given child if not already set.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited