computeSizeWithoutChild method
Returns the size when there is no child (just the padding dimensions).
Implementation
@override
Size computeSizeWithoutChild(BoxConstraints constraints) =>
Size(padding.horizontal, padding.vertical);
Returns the size when there is no child (just the padding dimensions).
@override
Size computeSizeWithoutChild(BoxConstraints constraints) =>
Size(padding.horizontal, padding.vertical);