performLayout method
Called to perform the actual layout computation for this render object.
Implementation
@override
void performLayout(Constraints constraints) {
size = const Size(3, 1);
}
Called to perform the actual layout computation for this render object.
@override
void performLayout(Constraints constraints) {
size = const Size(3, 1);
}