performLayout method
Called to perform the actual layout computation for this render object.
Implementation
@override
void performLayout(Constraints constraints) {
size = Size(10 + _labelWidth, 1);
}
Called to perform the actual layout computation for this render object.
@override
void performLayout(Constraints constraints) {
size = Size(10 + _labelWidth, 1);
}