setupParentData method
Initializes parentData for the given child if not already set.
Implementation
@override
void setupParentData(RenderObject child) {
if (child.parentData is! StackParentData) {
child.parentData = StackParentData();
}
}
Initializes parentData for the given child if not already set.
@override
void setupParentData(RenderObject child) {
if (child.parentData is! StackParentData) {
child.parentData = StackParentData();
}
}