Route<T> class abstract

An abstract route in the navigation stack, analogous to Flutter's Route.

Implementers

Constructors

Route({RouteSettings? settings})
Creates a Route.

Properties

canPop bool
Whether this route can be popped.
no setter
fullScreenRender bool
Whether this route renders as a full screen overlay.
no setter
hashCode int
The hash code for this object.
no setterinherited
isCurrent bool
Whether this route is the top-most route in the navigator.
no setter
isFirst bool
Whether this route is the first (root) route.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings?
Optional configuration for this route.
final

Methods

buildPage(BuildContext context) Widget
Builds the widget for this route's page.
didPop(T? result) → void
Called when this route has been popped off the navigator.
didPush() → void
Called when this route has been pushed onto the navigator.
didReplace(Route? oldRoute) → void
Called when this route has been replaced by another route.
dispose() → void
Called when this route has been removed from the navigator.
install() → void
Called when the route is first added to the navigator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited