didPop method
void
didPop(
- T? result
Called when this route has been popped off the navigator.
Implementation
void didPop(T? result) {}
Called when this route has been popped off the navigator.
void didPop(T? result) {}