fullScreenRender property
bool
get
fullScreenRender
Whether this route renders as a full screen overlay.
Implementation
bool get fullScreenRender => true;
Whether this route renders as a full screen overlay.
bool get fullScreenRender => true;