RouteAware class

An interface for objects that need to be notified about route changes, analogous to Flutter's RouteAware.

Constructors

RouteAware()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didPop() → void
Called when this object's route has been popped off the navigator.
didPopNext() → void
Called when the top route has been popped, exposing this object's route.
didPush() → void
Called when this object's route has been pushed onto the navigator.
didPushNext() → void
Called when a new route has been pushed on top of this object's route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited