RouteObserver<R extends Route> class

A NavigatorObserver that notifies RouteAware subscribers of route transitions, analogous to Flutter's RouteObserver.

Inheritance

Constructors

RouteObserver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didPop(Route route, Route? previousRoute) → void
Called when a route has been popped off the navigator.
override
didPush(Route route, Route? previousRoute) → void
Called when a route has been pushed onto the navigator.
override
didReplace({Route? newRoute, Route? oldRoute}) → void
Called when a route has been replaced by another route.
override
didStartUserGesture(Route route, Route? previousRoute) → void
Called when the user starts a gesture to navigate.
inherited
didStopUserGesture() → void
Called when the user stops a navigation gesture.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(RouteAware routeAware, R route) → void
Subscribes routeAware to receive notifications about route.
toString() String
A string representation of this object.
inherited
unsubscribe(RouteAware routeAware) → void
Unsubscribes routeAware from receiving route notifications.

Operators

operator ==(Object other) bool
The equality operator.
inherited