RouteSettings class

Configuration data for a Route, analogous to Flutter's RouteSettings.

Constructors

RouteSettings({String? name, Object? arguments})
Creates a RouteSettings.
const

Properties

arguments Object?
Optional arguments passed to the route.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the route (e.g., '/home').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited