Spacer class
Takes up empty space in a Flex container (Row or Column).
Expands to fill available space proportionally to its flex factor. Has no visual representation.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- Spacer
Constructors
Properties
- flex → int
-
The flex factor controlling how much space this spacer occupies.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates the Element for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited