build method
Describes the part of the user interface represented by this widget.
Implementation
@override
Widget build(BuildContext context) {
return Expanded(flex: flex, child: const SizedBox.shrink());
}
Describes the part of the user interface represented by this widget.
@override
Widget build(BuildContext context) {
return Expanded(flex: flex, child: const SizedBox.shrink());
}