StackParentData class

Parent data used by Positioned to specify a child's placement in a Stack.

Inheritance

Constructors

StackParentData()

Properties

bottom int?
The offset from the bottom edge of the stack.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int?
An explicit height for the child.
getter/setter pair
left int?
The offset from the left edge of the stack.
getter/setter pair
offset Offset
The resolved paint offset computed during layout.
getter/setter pair
The offset from the right edge of the stack.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int?
The offset from the top edge of the stack.
getter/setter pair
width int?
An explicit width for the child.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited