mounted property
bool
get
mounted
Whether this state object is currently in the tree.
Implementation
bool get mounted => _element != null;
Whether this state object is currently in the tree.
bool get mounted => _element != null;