unmount method
Removes this element from the tree and releases resources.
Implementation
@override
void unmount() {
_state.dispose();
super.unmount();
}
Removes this element from the tree and releases resources.
@override
void unmount() {
_state.dispose();
super.unmount();
}