StatefulWidget class abstract

A widget that has mutable state, analogous to Flutter's StatefulWidget.

Subclasses must implement createState to provide a State object.

Inheritance
Implementers

Constructors

StatefulWidget({Key? key})
Creates a StatefulWidget.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates the Element for this widget.
override
createState() State<StatefulWidget>
Creates the mutable state for this widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited