StatelessWidget class abstract

A widget that does not require mutable state, analogous to Flutter's StatelessWidget.

Subclasses must implement build to describe the widget's UI.

Inheritance
Implementers

Constructors

StatelessWidget({Key? key})
Creates a StatelessWidget.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
createElement() StatelessElement
Creates the Element for this widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited