StreamBuilder<T> constructor

const StreamBuilder<T>({
  1. Key? key,
  2. T? initialData,
  3. Stream<T>? stream,
  4. required AsyncWidgetBuilder<T> builder,
})

Creates a new StreamBuilder that builds itself based on the latest snapshot of interaction with the specified stream and whose build strategy is given by builder.

Implementation

const StreamBuilder({
  super.key,
  this.initialData,
  this.stream,
  required this.builder,
});