initialData property
T?
initialData
final
The data that will be used to create the initial snapshot.
Implementation
final T? initialData;
The data that will be used to create the initial snapshot.
final T? initialData;