Tab class

A single tab entry displayed in a TabBar.

Provide either text or icon (or both) for the tab's appearance.

Constructors

Tab({String? text, String? icon})
Creates a Tab with optional text and icon.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String?
The icon character displayed on the tab.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text label displayed on the tab.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited