TabBarView class
Displays the content corresponding to the active tab in a TabBar.
Shows one child at a time based on the TabController.index. Must receive the same controller as the paired TabBar.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- TabBarView
Constructors
-
TabBarView({Key? key, required TabController controller, required List<
Widget> children}) -
Creates a TabBarView with the given
controllerandchildren.const
Properties
-
children
→ List<
Widget> -
The list of child widgets, one per tab.
final
- controller → TabController
-
The controller that determines which child is visible.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates the Element for this widget.
inherited
-
createState(
) → State< TabBarView> -
Creates the mutable state for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited