TerminalBackend class abstract

Abstract interface for low-level terminal I/O operations.

Implementers

Constructors

TerminalBackend()

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
The number of rows in the terminal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The number of columns in the terminal.
no setter

Methods

clear() → void
Clears the terminal screen.
flush() → void
Flushes any buffered output to the terminal.
hideCursor() → void
Hides the terminal cursor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCursorPosition(int x, int y) → void
Moves the cursor to the given x (column) and y (row) position.
showCursor() → void
Shows the terminal cursor.
toString() String
A string representation of this object.
inherited
write(String data) → void
Writes data to the terminal output.

Operators

operator ==(Object other) bool
The equality operator.
inherited