TestKeyboard class

Implemented types

Constructors

TestKeyboard()

Properties

hashCode int
The hash code for this object.
no setterinherited
keyEvents Stream<KeyEvent>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
initialize() → void
override
inputTest(String input) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendArrowDown() → void
sendArrowLeft() → void
sendArrowRight() → void
sendArrowUp() → void
sendBackspace() → void
sendChar(String char) → void
sendDelete() → void
sendEnd() → void
sendEnter() → void
sendEscape() → void
sendHome() → void
sendKey(KeyCode code, {String? char, bool isShiftPressed = false}) → void
sendKeyEvent(KeyEvent event) → void
sendShiftTab() → void
sendSpace() → void
sendTab() → void
toString() String
A string representation of this object.
inherited
typeText(String text) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited