clearAll method
Clears both the grid and the terminal, forcing a full redraw on next flush.
Implementation
@override
void clearAll() {
_output.clear();
_clearStyleGrid();
terminal.clear();
}
Clears both the grid and the terminal, forcing a full redraw on next flush.
@override
void clearAll() {
_output.clear();
_clearStyleGrid();
terminal.clear();
}