smartClear method
Fills the grid with empty cells while preserving the previous frame for diffing.
Implementation
@override
void smartClear() {
_output.clear();
_clearStyleGrid();
terminal.clear();
}
Fills the grid with empty cells while preserving the previous frame for diffing.
@override
void smartClear() {
_output.clear();
_clearStyleGrid();
terminal.clear();
}