clear method
void
clear()
Clears all text and resets the cursor to the start.
Implementation
void clear() {
_text = '';
_cursorPosition = 0;
clearSelection();
notifyListeners();
}
Clears all text and resets the cursor to the start.
void clear() {
_text = '';
_cursorPosition = 0;
clearSelection();
notifyListeners();
}