clearSelection method
void
clearSelection()
Clears the current text selection without modifying the text.
Implementation
void clearSelection() {
_selectionStart = null;
_selectionEnd = null;
}
Clears the current text selection without modifying the text.
void clearSelection() {
_selectionStart = null;
_selectionEnd = null;
}