moveCursorToEnd method
void
moveCursorToEnd()
Moves the cursor to the end of the text.
Implementation
void moveCursorToEnd() {
_cursorPosition = _text.length;
clearSelection();
notifyListeners();
}
Moves the cursor to the end of the text.
void moveCursorToEnd() {
_cursorPosition = _text.length;
clearSelection();
notifyListeners();
}