moveCursorToStart method
void
moveCursorToStart()
Moves the cursor to the beginning of the text.
Implementation
void moveCursorToStart() {
_cursorPosition = 0;
clearSelection();
notifyListeners();
}
Moves the cursor to the beginning of the text.
void moveCursorToStart() {
_cursorPosition = 0;
clearSelection();
notifyListeners();
}