controller property
An optional external controller for the text content and selection.
Implementation
final TextEditingController? controller;
An optional external controller for the text content and selection.
final TextEditingController? controller;