isExpandable property
An optional predicate that returns whether node can be expanded.
Implementation
final bool Function(T node)? isExpandable;
An optional predicate that returns whether node can be expanded.
final bool Function(T node)? isExpandable;