VerticalDivider class

A vertical line that separates content.

Draws a character (default ) with optional width and thickness.

Inheritance

Constructors

VerticalDivider({Key? key, int? width, int? thickness, Color? color, String? character})
Creates a VerticalDivider with optional width, thickness, and color.
const

Properties

character String?
The character used to draw the line; defaults to .
final
color Color?
The color of the divider line.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness int?
The number of columns actually drawn as the divider line.
final
width int?
The total width allocated for the divider.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates the Element for this widget.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited