WidgetTester class

Constructors

WidgetTester()

Properties

binding TestBinding
final
hashCode int
The hash code for this object.
no setterinherited
line String
no setter
lines List<String>
no setter
nonEmptyLines List<String>
no setter
rootElement Element?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal TestTerminal
no setter

Methods

assertBackgroundColor(int x, int y, Color expected) → void
assertBuffer(List<List<String>> expected) → void
assertBufferLines(List<String> expected) → void
assertCellAt(int x, int y, String expected) → void
assertContains(String text) → void
assertForegroundColor(int x, int y, Color expected) → void
assertLine(int lineIndex, String expected) → void
assertStyleAt(int x, int y, TextStyle expected) → void
backgroundColorAt(int x, int y) Color?
cellAt(int x, int y) String
contains(String text) bool
containsPattern(RegExp pattern) bool
foregroundColorAt(int x, int y) Color?
getPlainText() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pump([Duration? duration]) Future<void>
pumpAndSettle() Future<void>
pumpWidget(Widget widget) → void
sendArrowDown() → void
sendArrowLeft() → void
sendArrowRight() → void
sendArrowUp() → void
sendBackspace() → void
sendChar(String char) → void
sendDelete() → void
sendEnd() → void
sendEnter() → void
sendEscape() → void
sendHome() → void
sendKey(KeyCode code, {String? char, bool isShiftPressed = false}) → void
sendKeyEvent(KeyEvent event) → void
sendShiftTab() → void
sendSpace() → void
sendTab() → void
state<T extends State<StatefulWidget>>() → T?
styleAt(int x, int y) TextStyle?
tap(Finder finder) → void
tapSpace(Finder finder) → void
toString() String
A string representation of this object.
inherited
typeText(String text) → void
unmount() → void
widget<T extends Widget>() → T?

Operators

operator ==(Object other) bool
The equality operator.
inherited