addPostFrameCallback method
Registers a callback that is invoked once at the end of the next frame.
Implementation
void addPostFrameCallback(FrameCallback callback) {
_postFrameCallbacks.add(callback);
scheduleFrame();
}
Registers a callback that is invoked once at the end of the next frame.
void addPostFrameCallback(FrameCallback callback) {
_postFrameCallbacks.add(callback);
scheduleFrame();
}