rootElement property
Element?
get
rootElement
The root element of the widget tree, or null if no app is running.
Implementation
Element? get rootElement => _rootElement;
The root element of the widget tree, or null if no app is running.
Element? get rootElement => _rootElement;