FlexParentData class

Parent data for children of flex-based render objects.

Inheritance

Constructors

FlexParentData()

Properties

fit FlexFit
Whether the child should be tightly or loosely fitted.
getter/setter pair
flex int
The flex factor controlling how space is distributed.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offset Offset
The position of this child within its parent.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited