isRelayoutBoundary property
bool
get
isRelayoutBoundary
Whether this render object acts as a relayout boundary.
Implementation
bool get isRelayoutBoundary => _relayoutBoundary;
Whether this render object acts as a relayout boundary.
bool get isRelayoutBoundary => _relayoutBoundary;