paint abstract method
Paints this render object into the given context at offset.
Implementation
void paint(PaintingContext context, Offset offset);
Paints this render object into the given context at offset.
void paint(PaintingContext context, Offset offset);