setRelayoutBoundary method
Marks this render object as a relayout boundary or not.
Implementation
void setRelayoutBoundary(bool value) {
_relayoutBoundary = value;
}
Marks this render object as a relayout boundary or not.
void setRelayoutBoundary(bool value) {
_relayoutBoundary = value;
}