Actions class

Inheritance

Constructors

Actions({Key? key, required Map<Type, Action<Intent>> actions, required Widget child})
const

Properties

actions Map<Type, Action<Intent>>
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
inherited
createState() State<Actions>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

invoke(BuildContext context, Intent intent) Object?
lookup<T extends Intent>(BuildContext context) Action<Intent>?
lookupByType(Type intentType, BuildContext context) Action<Intent>?
of(BuildContext context) Map<Type, Action<Intent>>?