Align class

Positions its child within itself according to alignment.

For example, Align(alignment: Alignment.center, child: Text('hello')) centers the child within the Align widget's bounds.

Inheritance

Constructors

Align({Key? key, required Alignment alignment, Widget? child})
const

Properties

alignment Alignment
final
child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() SingleChildRenderObjectElement
inherited
createRenderObject(BuildContext context) RenderAlign
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, covariant RenderAlign renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited