AppBinding class
- Inheritance
-
- Object
- BindingBase
- AppBinding
- Mixed-in types
Constructors
- AppBinding([TerminalBackend? terminalBackend])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyboard → RawKeyboard
-
final
- outputBuffer ↔ OutputBuffer
-
latefinaloverride-getter
- rootElement → Element?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminal → Terminal
-
no setteroverride
Methods
-
addOverlay(
Widget overlay) → void -
inherited
-
addPersistentFrameCallback(
FrameCallback callback) → void -
inherited
-
addPostFrameCallback(
FrameCallback callback) → void -
inherited
-
addShutdownCallback(
ShutdownCallback callback) → void -
inherited
-
attachRootWidget(
Widget app) → void -
inherited
-
disposeServices(
) → void -
inherited
-
handleFrame(
) → void -
inherited
-
initializeServices(
) → void -
inherited
-
initInstances(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintElement(
Element element) → void -
inherited
-
removeOverlay(
Widget overlay) → void -
inherited
-
removePersistentFrameCallback(
FrameCallback callback) → void -
inherited
-
removeShutdownCallback(
ShutdownCallback callback) → void -
inherited
-
renderFrame(
) → void -
inherited
-
runApp(
Widget app) → void -
inherited
-
scheduleFrame(
) → void -
inherited
-
scheduleFrameWithClear(
) → void -
inherited
-
shutdown(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visibleCursor(
bool visible) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited