BoxConstraints.tightFor constructor
Creates constraints that are tight for the given dimensions.
If width or height is null, that dimension is unconstrained (0 to infinity).
Implementation
const BoxConstraints.tightFor({int? width, int? height})
: minWidth = width ?? 0,
maxWidth = width ?? Constraints.infinity,
minHeight = height ?? 0,
maxHeight = height ?? Constraints.infinity;