BuildContext class abstract
An abstract interface for locating ancestor widgets, analogous to Flutter's BuildContext.
BuildContext objects are passed to Widget.build methods and can be used to
look up inherited widgets and other ancestors in the tree.
- Implementers
- Available extensions
Constructors
Properties
- focusManager → FocusManager
-
Available on BuildContext, provided by the BuildContextNavigation extension
Returns the singleton FocusManager instance.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
Available on BuildContext, provided by the BuildContextNavigation extension
Returns the NavigatorState of the nearest Navigator ancestor.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dependOnInheritedWidgetOfExactType<
T extends InheritedWidget> () → T? -
Obtains the nearest InheritedWidget of type
T, registering the caller as a dependent. -
findAncestorElementOfExactType<
T extends InheritedWidget> () → InheritedElement? -
Returns the nearest InheritedElement of type
T. -
findAncestorWidgetOfExactType<
T extends Widget> () → T? -
Returns the nearest ancestor widget of the given type
T. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited