BuildContext class abstract

Implementers
Available extensions

Constructors

BuildContext()

Properties

focusManager FocusManager

Available on BuildContext, provided by the BuildContextNavigation extension

no setter
hashCode int
The hash code for this object.
no setterinherited

Available on BuildContext, provided by the BuildContextNavigation extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependOnInheritedWidgetOfExactType<T extends InheritedWidget>() → T?
findAncestorElementOfExactType<T extends InheritedWidget>() InheritedElement?
findAncestorWidgetOfExactType<T extends Widget>() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited