Builder class
A stateless utility widget that calls a builder callback to obtain its child.
Useful for obtaining a BuildContext that is a child of a different widget without introducing a new widget subclass.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- Builder
Constructors
- Builder({Key? key, required WidgetBuilder builder})
-
Creates a Builder that calls
builderto obtain its child.const
Properties
- builder → WidgetBuilder
-
The callback invoked during build to create the child widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates the Element for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited