ButtonStyle class

Constructors

ButtonStyle({Color foregroundColor = Color.white, Color backgroundColor = Color.blue, Color focusColor = Color.brightWhite, Color focusBackgroundColor = Color.brightBlue, Color disabledColor = Color.brightBlack, Color disabledBackgroundColor = Color.black, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 2, vertical: 0), bool bold = false})
const

Properties

backgroundColor Color
final
bold bool
final
disabledBackgroundColor Color
final
disabledColor Color
final
focusBackgroundColor Color
final
focusColor Color
final
foregroundColor Color
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? foregroundColor, Color? backgroundColor, Color? focusColor, Color? focusBackgroundColor, Color? disabledColor, Color? disabledBackgroundColor, EdgeInsets? padding, bool? bold}) ButtonStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited