CallbackAction class
An Action subclass that delegates invocation to a callback.
Constructors
- CallbackAction({required Object? onInvoke(Intent)})
-
Creates a CallbackAction that calls
onInvokewhen triggered.
Properties
Methods
-
invoke(
Intent intent) → Object? -
Invokes this action with the given
intent.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited