Card class
A material-design-inspired card with an optional background color, border, and padding.
Renders a box-drawing character border around its child. Without a child, defaults to a zero-sized SizedBox.
- Inheritance
Constructors
Properties
- child → Widget?
-
The optional child widget.
finalinherited
- color → Color?
-
The background color applied to the card border and fill.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- padding → EdgeInsets?
-
The inner padding between the border and the child.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → SingleChildRenderObjectElement -
Creates the Element for this widget.
inherited
-
createRenderObject(
BuildContext context) → RenderCard -
Creates the RenderObject for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
Updates the
renderObjectto reflect the current widget configuration.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited