Card class

A material-design-inspired card with an optional background color, border, and padding.

Renders a box-drawing character border around its child. Without a child, defaults to a zero-sized SizedBox.

Inheritance

Constructors

Card({Key? key, Widget? child, Color? color, EdgeInsets? padding})
const

Properties

child Widget?
finalinherited
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() SingleChildRenderObjectElement
inherited
createRenderObject(BuildContext context) RenderCard
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited