ChangeNotifier class
A class that can be extended or mixed in that provides a change notification API.
This class maintains a list of listeners that can be notified when the object changes. It's useful for implementing the observer pattern.
Example:
class MyModel extends ChangeNotifier {
int _value = 0;
int get value => _value;
void increment() {
_value++;
notifyListeners();
}
}
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
dynamic listener()) → void - Register a closure to be called when the object changes.
-
dispose(
) → void - Discards any resources used by the object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void - Call all the registered listeners.
-
removeListener(
dynamic listener()) → void - Remove a previously registered closure from the list of closures that are notified when the object changes.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited