Checkbox class
A material-design checkbox that toggles between checked (✓) and unchecked states.
Responds to KeyCode.space and KeyCode.enter to toggle. Wrap in Focus to enable keyboard navigation.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- Checkbox
Constructors
Properties
- activeColor → Color?
-
final
- checkColor → Color?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
-
onChanged
→ ValueChanged<
bool?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tristate → bool
-
final
- value → bool
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< Checkbox> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited