CircularProgressIndicator class

Inheritance

Constructors

CircularProgressIndicator({Key? key, Color? color, Color? backgroundColor, String? label, Duration speed = const Duration(milliseconds: 80), List<String>? frames})
const

Properties

backgroundColor Color?
final
color Color?
final
frames List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed Duration
final

Methods

createElement() StatefulElement
inherited
createState() State<CircularProgressIndicator>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited