Color class

A terminal color using ANSI 16-color palette values (0–15).

Use Color.transparent (-1) to indicate no color. See also Colors for named constants.

Constructors

Color(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

black → const Color
blue → const Color
brightBlack → const Color
brightBlue → const Color
brightCyan → const Color
brightGreen → const Color
brightMagenta → const Color
brightRed → const Color
brightWhite → const Color
brightYellow → const Color
cyan → const Color
green → const Color
magenta → const Color
red → const Color
transparent → const Color
white → const Color
yellow → const Color