Colors class
Predefined Color constants following material naming conventions.
Provides the same ANSI 16-color palette as Color plus additional semantic colors like Colors.black54.
Constructors
- Colors()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- black → const Color
- black54 → const Color
- blue → const Color
- brightBlack → const Color
- brightBlue → const Color
- brightCyan → const Color
- brightGreen → const Color
- brightMagenta → const Color
- brightRed → const Color
- brightWhite → const Color
- brightYellow → const Color
- cyan → const Color
- green → const Color
- magenta → const Color
- red → const Color
- transparent → const Color
- white → const Color
- yellow → const Color