Column class
A Flex that lays out children in a vertical line.
Use MainAxisAlignment and CrossAxisAlignment to control spacing. Children can be wrapped in Expanded or Flexible to distribute space. A Flex that lays out children in a vertical line.
Use MainAxisAlignment and CrossAxisAlignment to control spacing. Children can be wrapped in Expanded or Flexible to distribute space.
- Inheritance
Constructors
-
Column({Key? key, required List<
Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisSize mainAxisSize = MainAxisSize.max}) -
const
Properties
-
children
→ List<
Widget> -
finalinherited
- crossAxisAlignment → CrossAxisAlignment
-
finalinherited
- direction → Axis
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
finalinherited
- mainAxisSize → MainAxisSize
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → MultiChildRenderObjectElement -
inherited
-
createRenderObject(
BuildContext context) → RenderFlex -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited