ComponentElement class abstract

Inheritance
Implemented types
Implementers
Available extensions

Constructors

ComponentElement(Widget widget)

Properties

dirty bool
getter/setter pairinherited
focusManager FocusManager

Available on BuildContext, provided by the BuildContextNavigation extension

no setter
hashCode int
The hash code for this object.
no setterinherited

Available on BuildContext, provided by the BuildContextNavigation extension

no setter
parent Element?
no setterinherited
renderObject RenderObject?
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
getter/setter pairinherited

Methods

build() Widget
dependOnInheritedWidgetOfExactType<T extends InheritedWidget>() → T?
inherited
findAncestorElementOfExactType<T extends InheritedWidget>() InheritedElement?
inherited
findAncestorWidgetOfExactType<T extends Widget>() → T?
inherited
markNeedsBuild() → void
inherited
mount(Element? parent) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild() → void
toString() String
A string representation of this object.
inherited
unmount() → void
inherited
update(Widget newWidget) → void
override
updateChild(Element? child, Widget newWidget) Element?
inherited
visitChildren(void visitor(Element e)) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited