Container class
A convenience widget that combines common painting, positioning, and sizing.
Supports color background, width/height constraints, padding, margin, and box-drawing border characters.
- Inheritance
Constructors
- Container({Key? key, Widget? child, Color? color, int? width, int? height, EdgeInsets? padding, EdgeInsets? margin, Border? border})
-
const
Properties
- border → Border?
-
final
- child → Widget?
-
finalinherited
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
final
- key → Key?
-
finalinherited
- margin → EdgeInsets?
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
final
Methods
-
createElement(
) → SingleChildRenderObjectElement -
inherited
-
createRenderObject(
BuildContext context) → RenderContainer -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited