DataColumn class

Constructors

DataColumn({required String label, bool numeric = false, void onSort(int columnIndex, bool ascending)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
numeric bool
final
onSort → void Function(int columnIndex, bool ascending)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited