DataTable class
A table widget that displays data in rows and columns with configurable headers, cell alignment, and optional row selection.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- DataTable
Constructors
Properties
-
columns
→ List<
DataColumn> -
The column definitions for the table header.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
-
rows
→ List<
DataRow> -
The data rows to display.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCheckboxColumn → bool
-
Whether to show a checkbox column for row selection.
final
- sortAscending → bool
-
Whether the sort is ascending.
final
- sortColumnIndex → int?
-
The index of the column currently used for sorting, or
null.final
Methods
-
createElement(
) → StatefulElement -
Creates the Element for this widget.
inherited
-
createState(
) → State< DataTable> -
Creates the mutable state for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited