DataTable class

Inheritance

Constructors

DataTable({Key? key, required List<DataColumn> columns, required List<DataRow> rows, int? sortColumnIndex, bool sortAscending = true, bool showCheckboxColumn = false})
const

Properties

columns List<DataColumn>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
rows List<DataRow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCheckboxColumn bool
final
sortAscending bool
final
sortColumnIndex int?
final

Methods

createElement() StatefulElement
inherited
createState() State<DataTable>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited