DefaultTabController class
- Inheritance
-
- Object
- Widget
- InheritedWidget
- DefaultTabController
Constructors
- DefaultTabController({Key? key, required TabController controller, required Widget child})
-
const
Properties
- child → Widget
-
finalinherited
- controller → TabController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant DefaultTabController oldWidget) → bool -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → TabController?