DefaultTextStyle class

Inheritance

Constructors

DefaultTextStyle({Key? key, required TextStyle style, required Widget child})
const

Properties

child Widget
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle
final

Methods

createElement() InheritedElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(covariant DefaultTextStyle oldWidget) bool
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) TextStyle
of(BuildContext context) TextStyle