Dialog class

A modal dialog with a title, message, and optional action buttons.

Use showDialog to display. Actions are laid out in a row at the bottom. Pressing Escape or the escape key dismisses the dialog.

Inheritance

Constructors

Dialog({Key? key, required Widget child, String? title, List<Widget>? actions, EdgeInsets? padding, TextStyle? titleStyle, Color backgroundColor = Colors.white})
const

Properties

actions List<Widget>?
final
backgroundColor Color
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
titleStyle TextStyle?
final

Methods

build(BuildContext context) Widget
override
createElement() StatelessElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited