Divider class

Inheritance

Constructors

Divider({Key? key, int? height, int? thickness, Color? color, String? character})
const

Properties

character String?
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness int?
final

Methods

build(BuildContext context) Widget
override
createElement() StatelessElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited