DropdownButton<T> class

Inheritance

Constructors

const

Properties

backgroundColor Color?
final
final
focusColor Color?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
items List<DropdownMenuItem<T>>
final
key Key?
finalinherited
onChanged ValueChanged<T?>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final

Methods

createElement() StatefulElement
inherited
createState() State<DropdownButton<T>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited