EdgeInsets class

Immutable insets for each edge of a terminal rectangle.

Follows Flutter's EdgeInsets API: EdgeInsets.all, EdgeInsets.symmetric, EdgeInsets.only, and EdgeInsets.fromLTRB.

Constructors

EdgeInsets.all(int v)
const
EdgeInsets.fromLTRB(int left, int top, int right, int bottom)
const
EdgeInsets.only({int top = 0, int right = 0, int bottom = 0, int left = 0})
const
EdgeInsets.symmetric({int vertical = 0, int horizontal = 0})
const

Properties

bottom int
final
hashCode int
The hash code for this object.
no setteroverride
horizontal int
no setter
left int
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int
final
vertical int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(EdgeInsets other) EdgeInsets
operator ==(Object other) bool
The equality operator.
override

Constants

zero → const EdgeInsets