Element class abstract

Implementers

Constructors

Element(Widget widget)

Properties

dirty bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parent Element?
no setter
renderObject RenderObject?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
getter/setter pair

Methods

dependOnInheritedWidgetOfExactType<T extends InheritedWidget>() → T?
findAncestorElementOfExactType<T extends InheritedWidget>() InheritedElement?
findAncestorWidgetOfExactType<T extends Widget>() → T?
markNeedsBuild() → void
mount(Element? parent) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unmount() → void
update(Widget newWidget) → void
updateChild(Element? child, Widget newWidget) Element?
visitChildren(void visitor(Element e)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited