ExpansionTile class

Inheritance

Constructors

ExpansionTile({Key? key, required String title, List<Widget> children = const [], bool initiallyExpanded = false, ValueChanged<bool>? onExpansionChanged, ExpansionTileController? controller, Color? expandedColor, Color? collapsedColor, Color? iconColor, FocusNode? focusNode})
const

Properties

children List<Widget>
final
collapsedColor Color?
final
controller ExpansionTileController?
final
expandedColor Color?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
initiallyExpanded bool
final
key Key?
finalinherited
onExpansionChanged ValueChanged<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

createElement() StatefulElement
inherited
createState() State<ExpansionTile>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited