Finder class abstract
- Implementers
Constructors
- Finder()
-
const
Properties
- evaluatesToSingleWidget → bool
-
no setter
- exists → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
byKey(
Key key) → Finder -
byType<
T extends Widget> () → Finder -
evaluate(
) → Element? -
evaluateAll(
) → List< Element> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
text(
String text) → Finder -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited