Flex class
- Inheritance
- Implementers
Constructors
-
Flex({Key? key, required List<
Widget> children, required Axis direction, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisSize mainAxisSize = MainAxisSize.max}) -
const
Properties
-
children
→ List<
Widget> -
finalinherited
- crossAxisAlignment → CrossAxisAlignment
-
final
- direction → Axis
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- mainAxisSize → MainAxisSize
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → MultiChildRenderObjectElement -
inherited
-
createRenderObject(
BuildContext context) → RenderFlex -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited