Focus class

Inheritance

Constructors

Focus({Key? key, FocusNode? focusNode, dynamic onKeyEvent(KeyEvent)?, required Widget child})
const

Properties

child Widget
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
onKeyEvent → dynamic Function(KeyEvent)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
inherited
createState() State<Focus>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited