FocusManager class
- Inheritance
-
- Object
- NavigatorObserver
- FocusManager
Properties
- currentFocus → FocusNode?
-
no setter
- currentScope → FocusScope?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
didPop(
Route route, Route? previousRoute) → void -
override
-
didPush(
Route route, Route? previousRoute) → void -
override
-
didReplace(
{Route? newRoute, Route? oldRoute}) → void -
override
-
didStartUserGesture(
Route route, Route? previousRoute) → void -
inherited
-
didStopUserGesture(
) → void -
inherited
-
dispose(
) → void -
initialize(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popDialogScope(
) → void -
pushDialogScope(
) → void -
registerNode(
FocusNode node) → void -
requestFocus(
FocusNode node) → void -
setTestKeyEvents(
Stream< KeyEvent> stream) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterNode(
FocusNode node) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → FocusManager
-
no setter