FocusNode class

Inheritance

Constructors

FocusNode({bool canRequestFocus = true})

Properties

canRequestFocus bool
getter/setter pair
hasFocus bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
onKeyEvent ↔ dynamic Function(KeyEvent)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trapFocus bool
getter/setter pair

Methods

addListener(dynamic listener()) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(dynamic listener()) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
requestFocus() → void
toString() String
A string representation of this object.
inherited
unfocus() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited