FocusScope class
Constructors
Properties
- currentFocus → FocusNode?
-
no setter
- focusedChild → FocusNode?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
no setter
-
nodes
→ List<
FocusNode> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activate(
) → void -
addNode(
FocusNode node) → void -
deactivate(
) → void -
dispose(
) → void -
nextFocus(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previousFocus(
) → void -
removeNode(
FocusNode node) → void -
requestFocus(
FocusNode node) → void -
restoreFocus(
) → void -
setFocus(
FocusNode node) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited