Form class
A container for form fields that manages validation and submission.
Wrap FormField widgets in a Form to enable collective validation, reset, and submission handling via onSubmitted.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- Form
Constructors
Properties
- autovalidate → bool
-
Whether to automatically validate fields on every change.
final
- child → Widget
-
The widget tree containing FormField widgets to manage.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- onSubmitted → VoidCallback?
-
Called when the form is submitted and all fields are valid.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates the Element for this widget.
inherited
-
createState(
) → State< Form> -
Creates the mutable state for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited