Form class

Inheritance

Constructors

Form({Key? key, required Widget child, VoidCallback? onSubmitted, bool autovalidate = false})
const

Properties

autovalidate bool
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
onSubmitted VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
inherited
createState() State<Form>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited