FormField<T> class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- FormField
Constructors
-
FormField({Key? key, required T initialValue, String? validator(T?)?, void onSaved(T)?, required Widget builder(FormFieldState<
T> )}) -
const
Properties
-
builder
→ Widget Function(FormFieldState<
T> ) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → T
-
final
- key → Key?
-
finalinherited
- onSaved → void Function(T)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validator → String? Function(T?)?
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< FormField< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited