FormFieldState<T> class

Inheritance

Constructors

FormFieldState()

Properties

context BuildContext
no setterinherited
errorText String?
no setter
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
mounted bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
no setter
widget FormField<T>
no setterinherited

Methods

build(BuildContext context) Widget
override
didUpdateWidget(FormField<T> oldWidget) → void
inherited
dispose() → void
override
initState() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
save() → void
setState(void fn()) → void
inherited
setValue(T value) → void
toString() String
A string representation of this object.
inherited
validate() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited