FormScope class
An inherited widget that provides FormState to descendant widgets.
- Inheritance
-
- Object
- Widget
- InheritedWidget
- FormScope
Constructors
Properties
- child → Widget
-
The widget below this inherited widget in the tree.
finalinherited
- formState → FormState
-
The FormState provided to the tree below.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedElement -
Creates the Element for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant FormScope oldWidget) → bool -
Whether the widgets that depend on this widget should be rebuilt when
oldWidgetis replaced by this widget.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → FormScope? - Retrieves the nearest FormScope from the widget tree.