FormState class

Inheritance

Constructors

FormState()

Properties

context BuildContext
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
mounted bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Form
no setterinherited

Methods

build(BuildContext context) Widget
override
didUpdateWidget(Form oldWidget) → void
inherited
dispose() → void
inherited
initState() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(FormFieldState field) → void
reset() → void
save() → void
setState(void fn()) → void
inherited
submit() → void
toString() String
A string representation of this object.
inherited
unregister(FormFieldState field) → void
validate() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited