GridView<T> class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- GridView
Constructors
Properties
- crossAxisCount → int
-
final
- crossAxisSpacing → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialSelectedIndex → int
-
final
-
items
→ List<
T> -
final
- key → Key?
-
finalinherited
- mainAxisSpacing → int
-
final
- onItemSelected → void Function(int index, T item)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBuilder → Widget Function(T item)
-
final
- unselectedBuilder → Widget Function(T item)
-
final
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< GridView< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited