Icons class

Constructors

Icons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

arrowDown → const String
arrowDownAscii → const String
arrowLeft → const String
arrowLeftAscii → const String
arrowRight → const String
arrowRightAscii → const String
arrowUp → const String
arrowUpAscii → const String
check → const String
checkAscii → const String
cross → const String
crossAscii → const String
error → const String
file → const String
folder → const String
info → const String
minus → const String
plus → const String
settings → const String
warning → const String