KeyCode enum
Represents the type of key pressed on the keyboard.
Values
- unknown → const KeyCode
-
An unrecognized key.
- arrowUp → const KeyCode
-
The up arrow key.
- arrowDown → const KeyCode
-
The down arrow key.
- arrowLeft → const KeyCode
-
The left arrow key.
- arrowRight → const KeyCode
-
The right arrow key.
- enter → const KeyCode
-
The enter (return) key.
- space → const KeyCode
-
The space bar.
- escape → const KeyCode
-
The escape key.
- tab → const KeyCode
-
The tab key.
- backspace → const KeyCode
-
The backspace key.
- delete → const KeyCode
-
The delete key.
- home → const KeyCode
-
The home key.
- end → const KeyCode
-
The end key.
- pageUp → const KeyCode
-
The page up key.
- pageDown → const KeyCode
-
The page down key.
- insert → const KeyCode
-
The insert key.
- f1 → const KeyCode
-
The F1 function key.
- f2 → const KeyCode
-
The F2 function key.
- f3 → const KeyCode
-
The F3 function key.
- f4 → const KeyCode
-
The F4 function key.
- f5 → const KeyCode
-
The F5 function key.
- f6 → const KeyCode
-
The F6 function key.
- f7 → const KeyCode
-
The F7 function key.
- f8 → const KeyCode
-
The F8 function key.
- f9 → const KeyCode
-
The F9 function key.
- f10 → const KeyCode
-
The F10 function key.
- f11 → const KeyCode
-
The F11 function key.
- f12 → const KeyCode
-
The F12 function key.
- char → const KeyCode
-
A printable character key.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited