KeyEvent class

Constructors

KeyEvent({required KeyCode code, String? char, bool isShiftPressed = false, bool isAltPressed = false, bool isCtrlPressed = false, bool isMetaPressed = false})
const

Properties

char String?
final
code KeyCode
final
hashCode int
The hash code for this object.
no setterinherited
isAltPressed bool
final
isCtrlPressed bool
final
isMetaPressed bool
final
isShiftPressed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited