LayoutBuilder class
- Inheritance
-
- Object
- Widget
- StatelessWidget
- LayoutBuilder
Constructors
- LayoutBuilder({Key? key, required LayoutWidgetBuilder builder})
-
const
Properties
- builder → LayoutWidgetBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
override
-
createElement(
) → StatelessElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited