LayoutConstants class

Layout-related constants used across the framework.

Constructors

LayoutConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultContainerHeight → const int
defaultTerminalHeight → const int
defaultTerminalWidth → const int
maxHeight → const int
maxWidth → const int