LinearProgressIndicator class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- LinearProgressIndicator
Constructors
Properties
- backgroundColor → Color?
-
final
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicatorWidth → int?
-
final
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double?
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< LinearProgressIndicator> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited