ListView<T> class

Inheritance

Constructors

ListView({Key? key, required List<T> items, Widget selectedBuilder(T item)?, Widget unselectedBuilder(T item)?, int initialSelectedIndex = 0, void onItemSelected(int index, T item)?, bool wrapAroundNavigation = false, ScrollController? controller, int? itemExtent})
const

Properties

controller ScrollController?
final
hashCode int
The hash code for this object.
no setterinherited
initialSelectedIndex int
final
itemExtent int?
final
items List<T>
final
key Key?
finalinherited
onItemSelected → void Function(int index, T item)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBuilder Widget Function(T item)
final
unselectedBuilder Widget Function(T item)
final
wrapAroundNavigation bool
final

Methods

createElement() StatefulElement
inherited
createState() State<ListView<T>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited