MediaQueryData class
Constructors
- MediaQueryData({required Size size, EdgeInsets padding = EdgeInsets.zero})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
Methods
-
copyWith(
{Size? size, EdgeInsets? padding}) → MediaQueryData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override