ModalRoute<T> class
A route that displays a modal dialog with a barrier overlay.
Constructors
- ModalRoute({required WidgetBuilder builder, bool barrierDismissible = true, Color? barrierColor, Alignment alignment = Alignment.center, RouteSettings? settings})
-
Creates a ModalRoute that displays the widget built by
builder.
Properties
- alignment → Alignment
-
The alignment of the dialog within the screen.
final
- barrierColor → Color?
-
The color of the barrier behind the dialog.
final
- barrierDismissible → bool
-
Whether tapping outside the dialog dismisses it.
final
- builder → WidgetBuilder
-
Builds the dialog widget to display.
final
- canPop → bool
-
Whether this route can be popped.
no setterinherited
- fullScreenRender → bool
-
Whether this route renders as a full screen overlay.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCurrent → bool
-
Whether this route is the top-most route in the navigator.
no setterinherited
- isFirst → bool
-
Whether this route is the first (root) route.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → RouteSettings?
-
Optional configuration for this route.
finalinherited
Methods
-
buildPage(
BuildContext context) → Widget -
Builds the widget for this route's page.
override
-
didPop(
T? result) → void -
Called when this route has been popped off the navigator.
override
-
didPush(
) → void -
Called when this route has been pushed onto the navigator.
override
-
didReplace(
Route? oldRoute) → void -
Called when this route has been replaced by another route.
inherited
-
dispose(
) → void -
Called when this route has been removed from the navigator.
inherited
-
install(
) → void -
Called when the route is first added to the navigator.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited