ModalRoute<T> class
Constructors
- ModalRoute({required WidgetBuilder builder, bool barrierDismissible = true, Color? barrierColor, Alignment alignment = Alignment.center, RouteSettings? settings})
Properties
- alignment → Alignment
-
final
- barrierColor → Color?
-
final
- barrierDismissible → bool
-
final
- builder → WidgetBuilder
-
final
- canPop → bool
-
no setterinherited
- fullScreenRender → bool
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCurrent → bool
-
no setterinherited
- isFirst → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → RouteSettings?
-
finalinherited
Methods
-
buildPage(
BuildContext context) → Widget -
override
-
didPop(
T? result) → void -
override
-
didPush(
) → void -
override
-
didReplace(
Route? oldRoute) → void -
inherited
-
dispose(
) → void -
inherited
-
install(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited