MultiChildRenderObjectWidget class abstract
A RenderObjectWidget with a list of children, analogous to Flutter's MultiChildRenderObjectWidget.
- Inheritance
-
- Object
- Widget
- RenderObjectWidget
- MultiChildRenderObjectWidget
- Implementers
Constructors
-
MultiChildRenderObjectWidget({Key? key, required List<
Widget> children}) -
Creates a MultiChildRenderObjectWidget.
const
Properties
Methods
-
createElement(
) → MultiChildRenderObjectElement -
Creates the Element for this widget.
override
-
createRenderObject(
BuildContext context) → RenderObject -
Creates the RenderObject for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
Updates the
renderObjectto reflect the current widget configuration.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited