Navigator class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- Navigator
Constructors
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- home → Widget?
-
final
- initialRoute → String?
-
final
- key → Key?
-
finalinherited
-
observers
→ List<
NavigatorObserver> ? -
final
-
routes
→ Map<
String, RouteBuilder> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → NavigatorState -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- focusManager → FocusManager
-
no setter
Static Methods
-
of(
BuildContext context) → NavigatorState -
pop(
BuildContext context, [Object? result]) → bool -
popUntil(
BuildContext context, RoutePredicate predicate, [Object? result]) → void -
push<
T> (BuildContext context, Route route) → Future< T?> -
pushNamed<
T> (BuildContext context, String routeName, {Object? arguments}) → Future< T?> -
pushReplacement<
T> (BuildContext context, Route route, [Object? result]) → Future< T?> -
pushReplacementNamed<
T> (BuildContext context, String routeName, {Object? arguments, Object? result}) → Future< T?>