NavigatorState class
Constructors
Properties
- context → BuildContext
-
no setterinherited
- currentRoute → Route?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
Route> -
no setter
- mounted → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → Navigator
-
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
override
-
didUpdateWidget(
Navigator oldWidget) → void -
inherited
-
dispose(
) → void -
override
-
initState(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop(
[Object? result]) → bool -
popUntil(
RoutePredicate predicate, [Object? result]) → void -
push<
T> (Route route) → Future< T?> -
pushNamed<
T> (String routeName, {Object? arguments}) → Future< T?> -
pushReplacement<
T> (Route route, [Object? result]) → Future< T?> -
pushReplacementNamed<
T> (String routeName, {Object? arguments, Object? result}) → Future< T?> -
setState(
void fn()) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited