Offset class

An immutable 2D integer offset with x and y coordinates.

Used for positioning within the terminal grid (0-based).

Constructors

Offset(int x, int y)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
final
y int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(Offset other) Offset
operator -(Offset other) Offset
operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Offset