OutputBuffer class

Implementers

Constructors

OutputBuffer(Terminal terminal)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal Terminal
final

Methods

clear() → void
clearAll() → void
conditionalClear() → void
flush() → void
needsFullClear() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize() → void
smartClear() → void
toString() String
A string representation of this object.
inherited
write(int x, int y, String char) → void
writeStyled(int x, int y, String char, TextStyle? style) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited