OverlayEntry class
An entry in an Overlay, analogous to Flutter's OverlayEntry.
Constructors
- OverlayEntry({required Widget builder(BuildContext), bool opaque = false})
- Creates an OverlayEntry.
Properties
- builder → Widget Function(BuildContext)
-
The builder that creates this entry's widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this entry is currently mounted in an overlay.
no setter
- opaque → bool
-
Whether this entry covers the entire overlay.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → void - Removes this entry from its overlay.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited