OverlayState class

Inheritance

Constructors

OverlayState()

Properties

context BuildContext
no setterinherited
entries List<OverlayEntry>
no setter
hashCode int
The hash code for this object.
no setterinherited
mounted bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Overlay
no setterinherited

Methods

build(BuildContext context) Widget
override
didUpdateWidget(Overlay oldWidget) → void
inherited
dispose() → void
inherited
initState() → void
inherited
insert(OverlayEntry entry, {OverlayEntry? below, OverlayEntry? above}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(void fn()) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited