Padding class

Insets its child by the given padding.

For example, Padding(padding: EdgeInsets.all(2), child: Text('hi')) adds 2 cells of padding on all sides of the text.

Inheritance

Constructors

Padding({Key? key, required EdgeInsets padding, required Widget? child})
const

Properties

child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() SingleChildRenderObjectElement
inherited
createRenderObject(BuildContext context) RenderPadding
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited