PageRoute<T> class

Inheritance

Constructors

PageRoute({required RouteBuilder builder, RouteSettings? settings})

Properties

builder RouteBuilder
final
canPop bool
no setterinherited
fullScreenRender bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isCurrent bool
no setterinherited
isFirst bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings?
finalinherited

Methods

buildPage(BuildContext context) Widget
override
didPop(T? result) → void
inherited
didPush() → void
inherited
didReplace(Route? oldRoute) → void
inherited
dispose() → void
inherited
install() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited