Positioned class

Inheritance

Constructors

Positioned({Key? key, int? left, int? top, int? right, int? bottom, int? width, int? height, required Widget child})
const
Positioned.fill({Key? key, required Widget child})
const

Properties

bottom int?
final
child Widget
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height int?
final
key Key?
finalinherited
left int?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int?
final
width int?
final

Methods

applyParentData(RenderObject renderObject) → void
override
createElement() ParentDataElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited