Positioned class
- Inheritance
-
- Object
- Widget
- ParentDataWidget<
StackParentData> - Positioned
Constructors
Properties
- bottom → int?
-
final
- child → Widget
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
final
- key → Key?
-
finalinherited
- left → int?
-
final
- right → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int?
-
final
- width → int?
-
final
Methods
-
applyParentData(
RenderObject renderObject) → void -
override
-
createElement(
) → ParentDataElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited