RealTerminalBackend class

Implemented types

Constructors

RealTerminalBackend()

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
no setteroverride

Methods

clear() → void
override
dispose() → void
flush() → void
override
hideCursor() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCursorPosition(int x, int y) → void
override
showCursor() → void
override
toString() String
A string representation of this object.
inherited
write(String data) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited