RenderAlign class

Inheritance

Constructors

RenderAlign({required Alignment alignment})

Properties

alignment Alignment
getter/setter pair
child RenderBox?
getter/setter pairinherited
hasChild bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
isRelayoutBoundary bool
no setterinherited
needsPaint bool
no setterinherited
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
width int
no setterinherited

Methods

clearNeedsPaint() → void
inherited
computeChildOffset(Offset parentOffset, Size childSize) Offset
override
computeSizeFromChild(BoxConstraints constraints, Size childSize) Size
override
computeSizeWithoutChild(BoxConstraints constraints) Size
inherited
getConstraintsForChild(BoxConstraints constraints) BoxConstraints
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
inherited
performLayout(Constraints constraints) → void
inherited
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited