containerHeight property
int?
get
containerHeight
The fixed height, or null to size from the child.
Implementation
int? get containerHeight => _height;
set
containerHeight
(int? value)
Sets the fixed height and marks layout as needed.
Implementation
set containerHeight(int? value) {
if (_height == value) return;
_height = value;
markNeedsLayout();
}