containerWidth property
int?
get
containerWidth
The fixed width, or null to size from the child.
Implementation
int? get containerWidth => _width;
set
containerWidth
(int? value)
Sets the fixed width and marks layout as needed.
Implementation
set containerWidth(int? value) {
if (_width == value) return;
_width = value;
markNeedsLayout();
}