mainAxisSize property
MainAxisSize
get
mainAxisSize
How much space the flex should occupy on the main axis.
Implementation
MainAxisSize get mainAxisSize => _mainAxisSize;
set
mainAxisSize
(MainAxisSize v)
Sets the main axis size and marks the render object as needing layout.
Implementation
set mainAxisSize(MainAxisSize v) {
if (_mainAxisSize == v) return;
_mainAxisSize = v;
markNeedsLayout();
}