RenderObjectWidget class abstract

Inheritance
Implementers

Constructors

RenderObjectWidget({Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() RenderObjectElement
override
createRenderObject(BuildContext context) RenderObject
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited