RenderRadio class

Inheritance

Constructors

RenderRadio({required bool selected, required bool focused, required bool enabled, required Color activeColor, required Color focusColor, required Color checkColor, VoidCallback? onTap})

Properties

activeColor Color
getter/setter pair
checkColor Color
getter/setter pair
enabled bool
getter/setter pair
focusColor Color
getter/setter pair
focused bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
isRelayoutBoundary bool
no setterinherited
needsPaint bool
no setterinherited
onTap VoidCallback?
getter/setter pair
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pair
size Size?
getter/setter pairinherited
width int
no setterinherited

Methods

clearNeedsPaint() → void
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
override
performLayout(Constraints constraints) → void
override
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited