maxLines property

int? get maxLines

The maximum number of lines, or null for unlimited.

Implementation

int? get maxLines => _maxLines;
set maxLines (int? value)

Sets the max lines and marks layout as needed.

Implementation

set maxLines(int? value) {
  if (_maxLines == value) return;
  _maxLines = value;
  markNeedsLayout();
}