RenderSlider class

Inheritance

Constructors

RenderSlider({required int value, required int min, required int max, required bool focused, required bool enabled, required Color activeColor, required Color inactiveColor, required Color thumbColor, String? label})

Properties

activeColor Color
getter/setter pair
enabled bool
getter/setter pair
focused bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
inactiveColor Color
getter/setter pair
isRelayoutBoundary bool
no setterinherited
label String?
getter/setter pair
max int
getter/setter pair
min int
getter/setter pair
needsPaint bool
no setterinherited
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
thumbColor Color
getter/setter pair
value int
getter/setter pair
width int
no setterinherited

Methods

clearNeedsPaint() → void
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
override
performLayout(Constraints constraints) → void
override
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited