RenderStack class

Inheritance
Mixed-in types

Constructors

RenderStack()

Properties

children List<RenderBox>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
isRelayoutBoundary bool
no setterinherited
needsPaint bool
no setterinherited
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
width int
no setterinherited

Methods

add(RenderBox child) → void
inherited
clear() → void
inherited
clearNeedsPaint() → void
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
override
performLayout(Constraints constraints) → void
override
remove(RenderBox child) → void
inherited
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited