RenderTabBar class

Inheritance

Constructors

RenderTabBar({required List<Tab> tabs, required int currentIndex, required bool focused, required Color indicatorColor, required Color labelColor, required Color unselectedLabelColor, TextStyle? labelStyle, TextStyle? unselectedLabelStyle, required EdgeInsets labelPadding})

Properties

currentIndex int
getter/setter pair
focused bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
indicatorColor Color
getter/setter pair
isRelayoutBoundary bool
no setterinherited
labelColor Color
getter/setter pair
labelPadding EdgeInsets
getter/setter pair
labelStyle TextStyle?
getter/setter pair
needsPaint bool
no setterinherited
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
tabs List<Tab>
getter/setter pair
unselectedLabelColor Color
getter/setter pair
unselectedLabelStyle TextStyle?
getter/setter pair
width int
no setterinherited

Methods

clearNeedsPaint() → void
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
override
performLayout(Constraints constraints) → void
override
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited