maxLines property
int?
get
maxLines
The maximum number of lines, or null for unlimited.
Implementation
int? get maxLines => _maxLines;
set
maxLines
(int? v)
Sets the max lines and marks the render object as needing layout.
Implementation
set maxLines(int? v) {
if (_maxLines == v) return;
_maxLines = v;
_invalidateLayoutCache();
markNeedsLayout();
}