RenderTextField class

Inheritance

Constructors

RenderTextField({required String text, required int cursorPosition, String? placeholder, TextStyle? style, required bool hasFocus})

Properties

cursorPosition int
getter/setter pair
hasFocus bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasSize bool
no setterinherited
height int
no setterinherited
isRelayoutBoundary bool
no setterinherited
needsPaint bool
no setterinherited
parent RenderObject?
getter/setter pairinherited
parentData ParentData?
getter/setter pairinherited
placeholder String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
style TextStyle?
getter/setter pair
text String
getter/setter pair
width int
no setterinherited

Methods

clearNeedsPaint() → void
inherited
layout(Constraints constraints, {bool parentUsesSize = true}) → void
inherited
markNeedsLayout() → void
inherited
markNeedsPaint() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
override
performLayout(Constraints constraints) → void
override
setRelayoutBoundary(bool value) → void
inherited
setupParentData(RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited