RichText class
A widget that renders a TextSpan tree with mixed styles and line wrapping.
- Inheritance
-
- Object
- Widget
- RenderObjectWidget
- RichText
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- maxLines → int?
-
The maximum number of lines to display, or
nullfor unlimited.final - overflow → TextOverflow
-
How to handle text that overflows the maxLines limit.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → TextSpan
-
The root span of the styled text tree to render.
final
Methods
-
createElement(
) → RenderObjectElement -
Creates the Element for this widget.
override
-
createRenderObject(
BuildContext context) → RenderObject -
Creates the RenderObject for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
Updates the
renderObjectto reflect the current widget configuration.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited