RichText class

Inheritance

Constructors

RichText({Key? key, required TextSpan text, int? maxLines, TextOverflow overflow = TextOverflow.clip})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
maxLines int?
final
overflow TextOverflow
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text TextSpan
final

Methods

createElement() RenderObjectElement
override
createRenderObject(BuildContext context) RenderObject
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited