Route<T> class abstract

Implementers

Constructors

Route({RouteSettings? settings})

Properties

canPop bool
no setter
fullScreenRender bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isCurrent bool
no setter
isFirst bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings RouteSettings?
final

Methods

buildPage(BuildContext context) Widget
didPop(T? result) → void
didPush() → void
didReplace(Route? oldRoute) → void
dispose() → void
install() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited