RouteObserver<R extends Route> class
- Inheritance
-
- Object
- NavigatorObserver
- RouteObserver
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
didPop(
Route route, Route? previousRoute) → void -
override
-
didPush(
Route route, Route? previousRoute) → void -
override
-
didReplace(
{Route? newRoute, Route? oldRoute}) → void -
override
-
didStartUserGesture(
Route route, Route? previousRoute) → void -
inherited
-
didStopUserGesture(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
RouteAware routeAware, R route) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
RouteAware routeAware) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited