ScrollController class
Controls scroll position and notifies listeners of changes, analogous to Flutter's ScrollController.
- Inheritance
-
- Object
- ChangeNotifier
- ScrollController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- offset ↔ int
-
The current scroll offset in cells.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
dynamic listener()) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
int newOffset) → void -
Scrolls to the given
newOffset. -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
dynamic listener()) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited