Shortcuts class

Inheritance

Constructors

Shortcuts({Key? key, required Map<ShortcutActivator, Intent> shortcuts, required Widget child})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcuts Map<ShortcutActivator, Intent>
final

Methods

createElement() StatefulElement
inherited
createState() State<Shortcuts>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lookup(KeyEvent event, BuildContext context) Intent?
of(BuildContext context) Map<ShortcutActivator, Intent>?