SingleChildRenderObjectWidget class abstract
A RenderObjectWidget with a single optional child, analogous to Flutter's SingleChildRenderObjectWidget.
Constructors
- SingleChildRenderObjectWidget({Key? key, Widget? child})
-
Creates a SingleChildRenderObjectWidget.
const
Properties
Methods
-
createElement(
) → SingleChildRenderObjectElement -
Creates the Element for this widget.
override
-
createRenderObject(
BuildContext context) → RenderObject -
Creates the RenderObject for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
Updates the
renderObjectto reflect the current widget configuration.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited