SingleChildScrollView class

Inheritance

Constructors

SingleChildScrollView({Key? key, required Widget child, ScrollController? controller, Axis scrollDirection = Axis.vertical, EdgeInsets? padding, FocusNode? focusNode})
const

Properties

child Widget
final
controller ScrollController?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis
final

Methods

createElement() StatefulElement
inherited
createState() State<SingleChildScrollView>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited