Size class

An immutable 2D integer size with width and height.

Terminal cells are discrete, so coordinates are always integers.

Constructors

Size(int width, int height)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Size