SizedBox class

Inheritance

Constructors

SizedBox({Key? key, int width = 0, int height = 0, Widget? child})
const
SizedBox.shrink({Key? key, Widget? child})
const
SizedBox.square({Key? key, required int dimension, Widget? child})
const

Properties

child Widget?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height int
final
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

createElement() SingleChildRenderObjectElement
inherited
createRenderObject(BuildContext context) RenderSizedBox
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited