Slider class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- Slider
Constructors
Properties
- activeColor → Color?
-
final
- divisions → int?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveColor → Color?
-
final
- key → Key?
-
finalinherited
- label → String?
-
final
- max → int
-
final
- min → int
-
final
-
onChanged
→ ValueChanged<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbColor → Color?
-
final
- value → int
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< Slider> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited