Sparkline class
A compact inline chart that renders a list of numeric data as a sparkline.
Maps each value to a block character whose height is proportional to the value's position within the data range. Optionally set color for the bars.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- Sparkline
Constructors
Properties
- color → Color?
-
The color of the sparkline characters.
final
-
data
→ List<
double> -
The numeric values to render as a sparkline.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates the Element for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited