Stack class
A widget that layers its children on top of each other.
The first child is the base; subsequent children are painted on top. Use Positioned to place children at specific offsets within the stack.
- Inheritance
Properties
-
children
→ List<
Widget> -
The list of child widgets.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → MultiChildRenderObjectElement -
Creates the Element for this widget.
inherited
-
createRenderObject(
BuildContext context) → RenderStack -
Creates the RenderObject for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
Updates the
renderObjectto reflect the current widget configuration.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited