Stack class

Inheritance

Constructors

Stack({Key? key, required List<Widget> children})
const

Properties

children List<Widget>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() MultiChildRenderObjectElement
inherited
createRenderObject(BuildContext context) RenderStack
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited