State<T extends StatefulWidget> class abstract

Implementers

Constructors

State()

Properties

context BuildContext
no setter
hashCode int
The hash code for this object.
no setterinherited
mounted bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → T
no setter

Methods

build(BuildContext context) Widget
didUpdateWidget(T oldWidget) → void
dispose() → void
initState() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(void fn()) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited