StatefulWidget class abstract
A widget that has mutable state, analogous to Flutter's StatefulWidget.
Subclasses must implement createState to provide a State object.
- Inheritance
- Implementers
- Actions
- Button
- Checkbox
- CircularProgressIndicator
- DataTable
- DropdownButton
- ExpansionTile
- Focus
- Form
- FormField
- FutureBuilder
- GridView
- LinearProgressIndicator
- ListView
- MenuBar
- Navigator
- Overlay
- Radio
- ShortcutActionsHandler
- Shortcuts
- SingleChildScrollView
- Slider
- StreamBuilder
- TabBar
- TabBarView
- TextField
- TextFormField
- Toggle
- TreeView
Constructors
- StatefulWidget({Key? key})
-
Creates a StatefulWidget.
const
Properties
Methods
-
createElement(
) → StatefulElement -
Creates the Element for this widget.
override
-
createState(
) → State< StatefulWidget> - Creates the mutable state for this widget.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited