StatelessWidget class abstract
A widget that does not require mutable state, analogous to Flutter's StatelessWidget.
Subclasses must implement build to describe the widget's UI.
- Inheritance
- Implementers
Constructors
- StatelessWidget({Key? key})
-
Creates a StatelessWidget.
const
Properties
Methods
-
build(
BuildContext context) → Widget - Describes the part of the user interface represented by this widget.
-
createElement(
) → StatelessElement -
Creates the Element for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited