StatusBar class
A horizontal bar typically rendered at the bottom of the screen.
Displays left, center, and right widgets in a row with an optional backgroundColor and foregroundColor.
- Inheritance
-
- Object
- Widget
- StatelessWidget
- StatusBar
Constructors
Properties
- backgroundColor → Color?
-
The background color of the bar.
final
- center → Widget?
-
The widget displayed in the center of the bar.
final
- foregroundColor → Color?
-
The foreground (text) color applied to children.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
The height of the bar in terminal rows.
final
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- left → Widget?
-
The widget displayed on the left side of the bar.
final
- right → Widget?
-
The widget displayed on the right side of the bar.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates the Element for this widget.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited