StatusBar class

Inheritance

Constructors

StatusBar({Key? key, Widget? left, Widget? center, Widget? right, Color? backgroundColor, Color? foregroundColor, int height = 1})
const

Properties

backgroundColor Color?
final
center Widget?
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
key Key?
finalinherited
left Widget?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
override
createElement() StatelessElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited