TabBar class

Inheritance

Constructors

TabBar({Key? key, required List<Tab> tabs, TabController? controller, Color? indicatorColor, Color? labelColor, Color? unselectedLabelColor, TextStyle? labelStyle, TextStyle? unselectedLabelStyle, EdgeInsets? labelPadding, ValueChanged<int>? onTap, FocusNode? focusNode})
const

Properties

controller TabController?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
indicatorColor Color?
final
key Key?
finalinherited
labelColor Color?
final
labelPadding EdgeInsets?
final
labelStyle TextStyle?
final
onTap ValueChanged<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabs List<Tab>
final
unselectedLabelColor Color?
final
unselectedLabelStyle TextStyle?
final

Methods

createElement() StatefulElement
inherited
createState() State<TabBar>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited