TabBarView class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- TabBarView
Constructors
-
TabBarView({Key? key, required TabController controller, required List<
Widget> children}) -
const
Properties
-
children
→ List<
Widget> -
final
- controller → TabController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< TabBarView> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited