TabController class
Controls the active tab index for TabBar and TabBarView.
Notifies listeners when the index changes. Use DefaultTabController to provide a TabController to the widget tree via inheritance.
- Inheritance
-
- Object
- ChangeNotifier
- TabController
Constructors
- TabController({int initialIndex = 0, required int length})
-
Creates a TabController with the given
lengthand optionalinitialIndex.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- index → int
-
The current active tab index.
no setter
- length → int
-
The total number of tabs.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
dynamic listener()) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
int newIndex) → void -
Animates to the given
newIndex, clamped to valid range. -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
dynamic listener()) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited