TerminalBackend class abstract

Implementers

Constructors

TerminalBackend()

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
no setter

Methods

clear() → void
flush() → void
hideCursor() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCursorPosition(int x, int y) → void
showCursor() → void
toString() String
A string representation of this object.
inherited
write(String data) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited