TestBinding class
- Inheritance
-
- Object
- BindingBase
- TestBinding
- Mixed-in types
Constructors
- TestBinding({int width = 80, int height = 24})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyboard → TestKeyboard
-
final
- outputBuffer ↔ TestOutputBuffer
-
latefinaloverride-getter
- rootElement → Element?
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminal → TestTerminal
-
final
Methods
-
addOverlay(
Widget overlay) → void -
inherited
-
addPersistentFrameCallback(
FrameCallback callback) → void -
inherited
-
addPostFrameCallback(
FrameCallback callback) → void -
inherited
-
addShutdownCallback(
ShutdownCallback callback) → void -
inherited
-
attachRootWidget(
Widget app) → void -
inherited
-
disposeServices(
) → void -
inherited
-
handleFrame(
) → void -
inherited
-
initializeServices(
) → void -
inherited
-
initInstances(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintElement(
Element element) → void -
inherited
-
pump(
[Duration? duration]) → Future< void> -
pumpAndSettle(
) → Future< void> -
removeOverlay(
Widget overlay) → void -
inherited
-
removePersistentFrameCallback(
FrameCallback callback) → void -
inherited
-
removeShutdownCallback(
ShutdownCallback callback) → void -
inherited
-
renderFrame(
) → void -
inherited
-
runApp(
Widget app) → void -
inherited
-
runWidget(
Widget widget) → void -
scheduleFrame(
) → void -
inherited
-
scheduleFrameWithClear(
) → void -
inherited
-
shutdown(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unmount(
) → void -
visibleCursor(
bool visible) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → TestBinding
-
no setter
- maybeInstance → TestBinding?
-
no setter