TestOutputBuffer class

Implemented types

Constructors

TestOutputBuffer(TestTerminal terminal)

Properties

hashCode int
The hash code for this object.
no setterinherited
output List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal TestTerminal
final

Methods

backgroundColorAt(int x, int y) Color?
clear() → void
override
clearAll() → void
override
conditionalClear() → void
override
flush() → void
override
foregroundColorAt(int x, int y) Color?
needsFullClear() bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize() → void
override
resizeStyleGrid() → void
smartClear() → void
override
styleAt(int x, int y) TextStyle?
toString() String
A string representation of this object.
inherited
write(int x, int y, String char) → void
override
writeStringStyled(int x, int y, String text, TextStyle? style) → void
writeStyled(int x, int y, String char, TextStyle? style) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited