TestTerminal class
- Implemented types
Constructors
- TestTerminal({int width = 80, int height = 24})
Properties
- backend → TerminalBackend
-
no setteroverride
-
grid
→ List<
List< String> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
no setteroverride
- line → String
-
no setter
-
lines
→ List<
String> -
no setter
-
nonEmptyLines
→ List<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
no setteroverride
Methods
-
cellAt(
int x, int y) → String -
clear(
) → void -
override
-
contains(
String text) → bool -
containsPattern(
RegExp pattern) → bool -
getPlainText(
) → String -
hideCursor(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
override
-
setCursorPosition(
int x, int y) → void -
override
-
setSize(
int newWidth, int newHeight) → void -
showCursor(
) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String data) → void -
override
-
writeToGrid(
int x, int y, String char) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited