Text class
A run of text with optional styling.
Displays data in the terminal using the given style. Supports softWrap, maxLines, and TextOverflow modes.
- Inheritance
Constructors
Properties
- data → String
-
The text string to display.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another in the tree.
finalinherited
- maxLines → int?
-
The maximum number of lines to display, or
nullfor unlimited.final - overflow → TextOverflow
-
How visual overflow should be handled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softWrap → bool
-
Whether the text should wrap at word boundaries.
final
- style → TextStyle?
-
The style applied to the text.
final
Methods
-
createElement(
) → RenderObjectElement -
Creates the Element for this widget.
override
-
createRenderObject(
BuildContext context) → RenderText -
Creates the RenderObject for this widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
Updates the
renderObjectto reflect the current widget configuration.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited