Text class

A run of text with optional styling.

Displays data in the terminal using the given style. Supports softWrap, maxLines, and TextOverflow modes.

Inheritance

Constructors

Text(String data, {Key? key, TextStyle? style, bool softWrap = true, int? maxLines, TextOverflow overflow = TextOverflow.clip})
const

Properties

data String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
finalinherited
maxLines int?
final
overflow TextOverflow
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool
final
style TextStyle?
final

Methods

createElement() RenderObjectElement
override
createRenderObject(BuildContext context) RenderText
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, RenderObject renderObject) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited