Text class
A run of text with optional styling.
Displays data in the terminal using the given style. Supports softWrap, maxLines, and TextOverflow modes.
- Inheritance
Constructors
Properties
Methods
-
createElement(
) → RenderObjectElement -
override
-
createRenderObject(
BuildContext context) → RenderText -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRenderObject(
BuildContext context, RenderObject renderObject) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited