TextEditingController class
- Inheritance
-
- Object
- ChangeNotifier
- TextEditingController
Constructors
Properties
- cursorPosition ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasSelection → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → TextSelection?
-
no setter
- text ↔ String
-
getter/setter pair
Methods
-
addListener(
dynamic listener()) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void -
clearSelection(
) → void -
copy(
) → Future< void> -
cut(
) → Future< void> -
deleteBackward(
) → void -
deleteForward(
) → void -
deleteSelection(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
insertText(
String text) → void -
moveCursorLeft(
) → void -
moveCursorRight(
) → void -
moveCursorToEnd(
) → void -
moveCursorToStart(
) → void -
moveCursorWordLeft(
) → void -
moveCursorWordRight(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
paste(
) → Future< void> -
removeListener(
dynamic listener()) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
selectAll(
) → void -
setSelection(
int start, int end) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited