TextField class
A single-line or multi-line text input field.
Supports keyboard navigation, text selection, clipboard operations, and configurable maxLength. Use TextEditingController for programmatic access to the text and selection state. A single-line or multi-line text input field.
Supports keyboard navigation, text selection, clipboard, and configurable
obscureText for maxLines.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- TextField
Constructors
Properties
- controller → TextEditingController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- maxLength → int?
-
final
- onChanged → dynamic Function(String)?
-
final
- onSubmitted → dynamic Function(String)?
-
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< TextField> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited