TextFormField class

Inheritance

Constructors

TextFormField({Key? key, TextEditingController? controller, String? initialValue, String? validator(String?)?, void onSaved(String)?, String? placeholder, TextStyle? style, int? maxLength})
const

Properties

controller TextEditingController?
final
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
final
key Key?
finalinherited
maxLength int?
final
onSaved → void Function(String)?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
final
validator String? Function(String?)?
final

Methods

createElement() StatefulElement
inherited
createState() State<TextFormField>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited