TextStyle class
Describes the style of terminal text — color, weight, slant, and decorations.
TextStyles are immutable. Use merge to combine two styles, with the other style's non-null properties taking priority.
Constructors
Properties
- backgroundColor → Color?
-
The background color behind the text.
final
- bold → bool
-
Whether the text is rendered in bold weight.
final
- color → Color?
-
The foreground color of the text.
final
- dim → bool
-
Whether the text is rendered in dim/faint mode.
final
- fontFamily → FontFamily
-
The font family used to render the text.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- italic → bool
-
Whether the text is rendered in italic slant.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underline → bool
-
Whether the text is rendered with an underline decoration.
final
Methods
-
merge(
TextStyle? other) → TextStyle -
Returns a new TextStyle that merges this style with
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override