TextStyle class
Describes the style of terminal text — color, weight, slant, and decorations.
TextStyles are immutable. Use merge to combine two styles, with the other style's non-null properties taking priority.
Constructors
Properties
- backgroundColor → Color?
-
final
- bold → bool
-
final
- color → Color?
-
final
- dim → bool
-
final
- fontFamily → FontFamily
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- italic → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underline → bool
-
final
Methods
-
merge(
TextStyle? other) → TextStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override