ThemeData class

Constructors

ThemeData({Color primaryColor = Colors.blue, Color backgroundColor = Colors.black, Color textColor = Colors.white, Color selectedColor = Colors.blue, Color borderColor = Colors.white, Color dividerColor = Colors.white})
const

Properties

backgroundColor Color
final
borderColor Color
final
dividerColor Color
final
hashCode int
The hash code for this object.
no setteroverride
primaryColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color
final
textColor Color
final

Methods

copyWith({Color? primaryColor, Color? backgroundColor, Color? textColor, Color? selectedColor, Color? borderColor, Color? dividerColor}) ThemeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

dark ThemeData
no setter
light ThemeData
no setter