Toggle class

Inheritance

Constructors

Toggle({Key? key, required bool value, ValueChanged<bool>? onChanged, FocusNode? focusNode, Color? activeColor, Color? inactiveColor, String? label})
const

Properties

activeColor Color?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor Color?
final
key Key?
finalinherited
label String?
final
onChanged ValueChanged<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value bool
final

Methods

createElement() StatefulElement
inherited
createState() State<Toggle>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited