TreeController class

Inheritance

Constructors

TreeController({Set<Object>? initialExpandedKeys})

Properties

expandedKeys Set<Object>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(dynamic listener()) → void
Register a closure to be called when the object changes.
inherited
collapse(Object key) → void
collapseAll() → void
dispose() → void
Discards any resources used by the object.
override
expand(Object key) → void
expandAll(List<Object> allKeys) → void
isExpanded(Object key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(dynamic listener()) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggleExpansion(Object key) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited