TreeView<T> class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- TreeView
Constructors
Properties
- builder → Widget Function(T node, int depth, bool isExpanded)
-
final
- controller → TreeController?
-
final
- focusNode → FocusNode?
-
final
-
getChildren
→ List<
T> Function(T node) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpandable → bool Function(T node)?
-
final
- key → Key?
-
finalinherited
- nodeKey → Object Function(T node)
-
final
- onNodeSelected → void Function(T node)?
-
final
-
roots
→ List<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< TreeView< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited