Widget class abstract
The base class for all widgets, analogous to Flutter's Widget.
Widgets are immutable descriptions of part of a user interface. Each widget describes its own createElement method which creates an Element that manages the widget's position in the tree.
Properties
Methods
-
createElement(
) → Element - Creates the Element for this widget.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited